<?php
/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 */

session_start();
 // header('Set-Cookie: PHPSESSID= ' . session_id() . '; SameSite=strict; Secure=true; HttpOnly=true;');

if (isset($_POST['vconfextension']) && $_POST['vconfextension'] != '' && isset($_POST['encextenpass']) && $_POST['encextenpass'] != '' && isset($_POST['vidconfextension']) && 
    $_POST['vidconfextension'] != '') {

    define('ACCESSCONST', TRUE);

    require('db-connect.php');

    $extForExternal = $_POST['vconfextension'];
    $extenPassEnc = $_POST['encextenpass'];
    $vconfExtension = $_POST['vidconfextension'];

    // Check if the received external user extension, the corresponding encrypted password and the extension of the conference, match the data in the 'external_users' table
    $query = $mysqli->prepare("SELECT id, exten_for_external, exten_for_ext_pass, conf_extension FROM external_users WHERE exten_for_external = ? AND exten_for_ext_pass = ? AND conf_extension = ?");
    $query->bind_param("sss", $extForExternal, $extenPassEnc, $vconfExtension);
    $query->execute();
    $extqueryres = $query->get_result()->fetch_array();

    if (!$extqueryres) {

        http_response_code(400);
        exit();

    } else {

	if (is_dir('../textchat/' . $extForExternal . 'vconf' . '/uploads')) {

	    try {
	      array_map('unlink', glob('../textchat/' . $extForExternal . 'vconf' . '/uploads/*'));
	      if (glob('../textchat/' . $extForExternal . 'vconf' . '/uploads/*')) { throw new Exception('Directory not empty'); } else { throw new Exception(''); }
	    } catch (Exception $e) { if ($e->getMessage() == '') { $cmessage = 'success'; } else { $cmessage = 'failure'; } }

	} else { $cmessage = 'success'; }

    }

    $resresult = ["note" => $cmessage];

    echo json_encode($resresult);

} else {
       header("Location: ../login.php");
}

?>
