<?php
/**
 *  Copyright (C) 2022, 2024  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 */

 session_start();
 session_unset();
 setcookie ("PHPSESSID", "", time() - 3600, '/');
 session_destroy();
 header("Location: ../login.php");
 exit();

?>
