/**
 *  Copyright (C) 2022, 2024  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 *
 *  This is a modified version of the original file "phone.css"
 *  released under AGPL v3.0 and first modified in 2020.
 *  The copyright notice for the original content follows:
 *
 *  Copyright (c) 2020  - Conrad de Wet - All Rights Reserved.
 */

/* CSS_dhtmlxUi */

.NoSelect {
    -webkit-user-select: none;  /* Chrome all / Safari all */
    -moz-user-select: none;     /* Firefox all */
    -ms-user-select: none;      /* IE 10+ */
    user-select: none;          /* Likely future */
}

.UiText {
    font-family: Inter, sans-serif;
    color: #193b66;
    font-size: 15px; 
    margin-top: 8px;
}

.UiWindowField .UiText {
    font-weight: 500 !important;
}

.UiButtonBar {
    text-align:center; 
    border-top:1px solid #e6e6e6; 
    background-color:#F3F3F3; 
    height:49px;
    vertical-align: middle;
    line-height: 49px;
}

.UiButtonBar button {
    margin: 0px;
    line-height: 100%;
    padding: 6px 6px;
    border: 1px solid #417bba;
    background-color: #417bba;
    border-radius: 3px;
    min-width: 30px;
    min-height: 24px;
    font-family: Inter, sans-serif;
    color: #FFFFFF;
    font-size: 14px;
    margin-left: 1px;
    margin-right: 1px;
    margin-top: 8px;
    outline: none;
    cursor: pointer;
}

.UiButtonBar button:hover {
    background-color: #3a6ba1;
    border: 1px solid #3a6ba1;
    color: #FFFFFF;
}

.UiButtonBar button:active {
    border: 1px solid #285480;
    background-color: #285480;
    background-image: none;
    color: #FFFFFF;
}

.UiButtonBar button:focus {
    outline: none;
}

.UiButtonBar button:disabled {
    cursor: default;
    color: #CCCCCC;
}

.UiButtonBarHtml {
    position: absolute;
    left: 0px;
    width: 100%;
    bottom: 0px;
}

.UiWindowButtonBar {
    text-align:center; 
    height: 49px;
    vertical-align: middle;
    line-height: 49px;
    padding: 11px 0px;
}

.UiWindowButtonBar button {
    margin: 0px;
    line-height: 100%;
    padding: 6px 6px;
    border: 1px solid #417bba;
    background-color: #417bba;
    border-radius: 3px;
    min-width: 80px;
    font-family: Inter, sans-serif;
    color: #FFFFFF;
    font-size: 14px;
    margin-left: 1px;
    margin-right: 1px;
    outline: none;
    cursor: pointer;
}

.UiWindowButtonBar button:hover {
    background-color: #3a6ba1;
    border: 1px solid #3a6ba1;
    color: #FFFFFF;
}

.UiWindowButtonBar button:active {
    border: 1px solid #285480;
    background-color: #285480;
    background-image: none;
    color: #FFFFFF;
}

.UiWindowButtonBar button:focus {
    outline: none;
}

.UiWindowButtonBar button:disabled {
    cursor: default;
    color: #CCCCCC;
}

#logoSection {
    padding: 6px !important;
    border-top: 6px solid #f0f5fc;
    border-left: 6px solid #f0f5fc;
    border-radius: 0px !important;
    background-color: #fafafa;
    vertical-align: top;
}

#profileArea {
    padding: 6px !important;
    border-top: 6px solid #f0f5fc;
    border-left: 6px solid #f0f5fc;
    border-radius: 0px !important;
}

#contactsArea {
    padding: 6px !important;
    border-top: 6px solid #f0f5fc;
    border-left: 6px solid #f0f5fc;
    border-bottom: 6px solid #f0f5fc !important;
    border-radius: 0px !important;
}

#txtCnfExtns, #audioCnfExtns, #videoCnfExtns {
   position: relative;
   table-layout: auto;
   width: 100%;
   margin-top: 10px;
   border: 0;
}

#vidConfExternalTable {
   position: relative;
   table-layout: auto;
   width: 100%;
   border: 0;
}

#txtCnfExtns tr, #audioCnfExtns tr, #videoCnfExtns tr, #vidConfExternalTable tr {
   display: table-row;
   border: 0;
}

.tcHeaderTitle, .acHeaderTitle, .vcHeaderTitle {
   padding: 0px 4px 9px 0px !important;
   font-family: Inter, sans-serif;
   font-size: 13px;
   font-weight: 500;
   color: #3b3b3b;
   border: 0;
}

.euHeaderTitle {
   padding: 0px 0px 9px 4px !important;
   font-family: Inter, sans-serif;
   font-size: 13px;
   font-weight: 500;
   color: #3b3b3b;
   border: 0;
}

.tcbtnTableRow, .acbtnTableRow, .vcbtnTableRow, .btnTableRow {
   padding: 4px 0px;
   font-size: 14px;
   border: 0;
}

.txtConfExtension, .tConferenceTag, .tConferenceGroups, 
.audioConfExtension, .aConferenceTag, .aConferenceGroups,
.videoConfExtension, .vConferenceTag, .vConferenceGroups {
   width: 70px;
}


#confTableSection {
   display: block;
   margin: 38px 0px 20px 0px;
   font-family: Inter, sans-serif;
   color: #193b66;
   font-size: 16px;
   text-align: left;
   font-weight: 600;
}

.extConfExtension {
    width: 58px !important;
    margin: 0px 0px 0px 4px;
}

.extConfExtensionPass {
    width: 80px !important;
    margin: 0px 0px 0px 4px;
}

.vidConferenceExtension {
    width: 70px !important;
    margin: 0px 0px 0px 4px;
}

.vidConferenceTag {
    width: 40px;
    margin: 0px 0px 0px 4px;
}

.extConfExtensionLink {
    width: 86px;
    margin: 0px 20px 0px 4px;
}

/* .saveExtConfExtension, .saveTConfExtension, .saveAConfExtension, .saveVConfExtension, #cnfSaveGroup { */
.saveCnfBtn {
    display: inline-block;
    padding: 3px 8px 4px 8px;
    background-color: #6ac9aa;
    border: 1px solid #6ac9aa;
    font-family: Inter, sans-serif;
    font-weight: 700;
    color: #ffffff;
    font-size: 14px;
    border-radius: 4px;
    cursor: pointer;
}

/*.saveExtConfExtension:hover, .saveTConfExtension:hover, .saveAConfExtension:hover, .saveVConfExtension:hover, #cnfSaveGroup:hover { */
.saveCnfBtn:hover {
    background-color: #63bc9f;
    border: 1px solid #63bc9f;
    box-shadow: none  !important;
}

/*.saveExtConfExtension:active, .saveTConfExtension:active, .saveAConfExtension:active, .saveVConfExtension:active, #cnfSaveGroup:active { */
.saveCnfBtn:active {
    background-color: #58a88e;
    border: 1px solid #58a88e;
    box-shadow: none  !important;
} 

.rmGrpFrmDtbs {
    display: inline-block;
    margin: 0px 0px 0px 20px;
    color: #9e9e9e;
    cursor: pointer;
    font-size: 14px;
}

.rmGrpFrmDtbs:hover {
    color: #c00202;
}

.grpListRow {
    display: block;
    margin: 6px 10px;
}

.grpListDspl {
    display: inline-block;
}

.deleteExtRow {
  display: inline-block;
  margin: 2px 6px 0px 6px;
  font-weight: 900;
  cursor: pointer;
  color: #a8a8a8;
}

.tcDeleteExtRow, .acDeleteExtRow, .vcDeleteExtRow {
  display: inline-block;
  margin: 2px 14px 0px 14px;
  font-weight: 900;
  cursor: pointer;
  color: #a8a8a8;
}

.deleteExtRowDisabled {
  pointer-events: none !important;
}

.deleteExtRow:hover, .tcDeleteExtRow:hover, .acDeleteExtRow:hover, .vcDeleteExtRow:hover {
  color: #961818;
}

#addTextConfExt, #addAudioConfExt, #addVideoConfExt {
    display: block;
    margin: 15px 0px 36px 0px;
    padding: 6px 12px 7px 12px;
    background-color: #ffffff;
    border: 1px solid #65c98d;
    font-size: 14px;
    font-family: Inter, sans-serif;
    font-weight: 700;
    color: #8a8a8a;
    border-radius: 4px;
    cursor: pointer;
    outline: none;
}

#add_New_External_User {
    display: block;
    margin: 18px 0px 30px 0px;
    padding: 6px 12px 7px 12px;
    background-color: #ffffff;
    border: 1px solid #65c98d;
    font-size: 14px;
    font-family: Inter, sans-serif;
    font-weight: 700;
    color: #8a8a8a;
    border-radius: 4px;
    cursor: pointer;
    outline: none;
}

#add_New_External_User:hover, #addTextConfExt:hover, #addAudioConfExt:hover, #addVideoConfExt:hover {
    background-color: #f1fff7;
}

#add_New_External_User:active, #addTextConfExt:active, #addAudioConfExt:active, #addVideoConfExt:active {
    background-color: #e6fcef;
}

#Save_New_User_Password, #Save_New_User_Email {
    display: block;
    margin: 0px;
    padding: 4px 8px 5px 8px;
    border: 1px solid #4c84c2;
    background-color: #4c84c2;
    font-size: 15px;
    font-weight: 500;
    font-family: Inter, sans-serif;
    color: #FFFFFF;
    border-radius: 4px;
    cursor: pointer;
    outline: none;
}

#Save_New_User_Password:hover, #Save_New_User_Email:hover {
    border: 1px solid #396da8;
    background-color: #396da8;
    background-image: linear-gradient(#5686ba, #3b6fa8);
    color: #FFFFFF;
}

#Save_New_User_Password:active, #Save_New_User_Email:active {
    border: 1px solid #205b96;
    background-color: #205b96;
    background-image: none;
    color: #FFFFFF;
}

#Close_User_Account {
    display: inline;
    margin: 0px 0px 0px 6px;
    padding: 1px 6px 3px 6px;
    border: 1px solid #4c84c2;
    background-color: #ffffff;
    font-size: 15px;
    font-weight: 500;
    font-family: Inter, sans-serif;
    color: #336dae;
    border-radius: 4px;
    cursor: pointer;
    outline: none;
}

#Close_User_Account:hover {
    background-color: #eaf4ff;
}

#Close_User_Account:active {
    background-color: #d7eaff;
}

.UiInputText {
    margin-bottom: 22px !important;
    font-size: 15px !important;
    color: #333333 !important;
    width: 100% !important;
    padding-top: 8px !important;
    padding-bottom: 6px !important;
}

.UiWindowField {
    position: relative;
    padding-top: 8px;
    padding-bottom: 0px;
    padding-left: 5.7%;
    padding-right: 5.7%;
    font-family: Inter, sans-serif;
    color: #333333;
    font-size: 14px;
    line-height: 1.5;
    height: 100%;
    overflow-y: auto;
    overflow-x: hidden;
}

.PastePreviewContainer {
    display: block;
    width: 150px;
    height: 150px;
    border: 10px solid #FFFFFF;
    border-radius: 200px;
    background-color: #F3F3F3;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, 0.2);
}

.PastePreview {
    max-width: 340px;
    max-height : 340px;
    border: 1px solid #CCCCCC;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, 0.25);
    margin: 5px;
    background-color: #F3F3F3;
    border: 10px solid #FFFFFF;
    border-radius: 200px;
}

.FullScreenVideo{
    position: fixed !important;
    top: 0px !important;
    left: 0px !important;
    display: block;
    width: 100% !important;
    height: 100% !important;
    background-color: #000000 !important;
    margin: 0px !important;
    padding: 0px !important;
    z-index: 2147483647 !important;
}

.dtmfButtons{
    font-size: 20px;
    color: #222222;
    width: 40px;
    height: 40px;
    padding: 2px 4px 2px 4px;
    border: 1px solid #efefef;
}

.dtmfButtons:hover{
    color: #FFFFFF;
    background-color: #222222;
}

.dtmfButtons:active{
    color: #cccccc;
    background-color: #000000;
}

.dtmfButtons div {
    font-size: 20px;
    line-height: 9px;
    margin: 0px;
    margin: 6px 0px 0px 0px;
    padding: 0px;
}

.dtmfButtons span {
    display: block;
    font-size: 9px;
    margin: 3px 0px 0px 0px;
    padding: 0px;
}

textarea::placeholder {
    color: #686868;
}

/* CSS_TabPageTemplate */

audio{
    outline: none;
}

html {
    margin: 0px;
    padding: 0px;
    height: 100%;
}

body {
    height: 100%;
    margin-top: 0px;
    margin-bottom: 0px;
    padding: 0px;
    font-family: Inter, sans-serif;
    font-size: 14px;
    line-height: 1.5;
    cursor: default;
    background-color: #F0F5FC;
    overflow: hidden;
    user-select: none;
}

.pageContainer{
    min-width: 300px;
    margin-left: auto;
    margin-right: auto;
    height: 100%;
    margin-top: 0px;
    margin-bottom: 0px;
    padding: 0px;
}

.smallFlag {
    height: 12px !important;
    vertical-align: middle !important;
    display: inline-block !important;
    margin-right: 5px !important;
    border: 1px solid #868686 !important;
    border-radius: 2px !important;
    background-color: #868686 !important;
}

/* ScrollBar Styling */
.scroller {
    overflow-y: auto;
    /* Firefox */
    scrollbar-color: #516896 transparent;
}

.scroller::-webkit-scrollbar {
//    width: 10px;
    width: 8px;
    /* Width */
}

.scroller::-webkit-scrollbar-track {
    background: transparent;
    /* Track */
}

.scroller::-webkit-scrollbar-thumb {
    background: #516896;
    /* Handle */
    border-radius: 50px;
}

.scroller::-webkit-scrollbar-thumb:hover {
    background: #697ca2;
//    background: #516896;
    /* Handle on hover */
}

.NoItems {
    margin-top: 50px;
    margin-bottom: 50px;
    margin-left: auto;
    margin-right: auto;
    text-align: center;
    width: 200px;
    border: 2px dashed #9cb5d7;
    border-radius: 15px;
    padding: 20px;
    color: #9cb5d7 !important;
}

.SelectItemArrow {
    float: left;
    margin-top: -10px;
    margin-right: -16px;
    margin-left: -10px;
}

.helpFieldset {
    background-color: #f9f9f9;
    border-right: none;
    border-left: none;
    border-color: #293442;
    font-size: 13px;
    color: #515e6f;
}

.FormTextRight {
    display: inline-block;
    text-align: right;
    padding-right: 5px;
}

.textField {
    border: 1px solid #80add4 !important;
    border-radius: 5px;
    padding-left: 3px !important;
    line-height: 22px !important;
    background-color: #fafafa !important;
    box-shadow: inset 0px 0px 3px rgba(0, 0, 0, 0.25);
    box-sizing: border-box;
}

.contentLoading {
    display: none;
    /* Start Hidden - must activate me :) */
    margin-top: 15px;
    margin-bottom: 15px;
    border: 1px solid #CCCCCC;
    border-radius: 50px;
    background-color: #FFFFFF;
    text-align: center;
    color: #333333;
    width: 90%;
    margin-left: auto;
    margin-right: auto;
    /* Optional */
    box-shadow: inset 1px 1px 5px rgba(0, 0, 0, 0.25);
    line-height: 16px;
    font-size: 11px;
    background-color: #e6e6e6;
    background-image: repeating-linear-gradient(-45deg, #e6e6e6, #e6e6e6 10px, #cfd9e8 10px, #cfd9e8 20px);
}

.required:before {
    content: "\f069";
    font-family: FontAwesome;
    color: red;
    font-size: 7px;
    vertical-align: text-top;
    margin-right: 3px;
}

.on_white{
    color: #333333;
}
.on_white:hover{
    color: #F3F3F3;
}

/* CSS_HtmlElements */
/* ================ */
fieldset {
    border: 1px solid #333333;
    border-radius: 5px;
    text-align: left;
}

legend {
    line-height: initial !important;
    text-align: left;
}

hr {
    height: 1px;
    border: none;
    background-color: #CCCCCC;
    clear: both;
}

button {
    margin: 0px;
    line-height: 100%;
    padding-left: 6px;
    padding-right: 6px;
    border: 1px solid transparent;
    background-color: transparent;
    border-radius: 5px;
    min-width: 22px;
    min-height: 24px;
    font-family: Inter, sans-serif;
    color: #9a9a9a;
    font-size: 14px;
    margin-left: 1px;
    margin-right: 1px;
    outline: none;
    cursor: pointer;
}

button:hover {
    background-color: #333333;
    border: 1px solid #404040;
    color: #FFFFFF;
}

button:active {
    border: 1px solid #333333;
    background-color: #222222;
    background-image: none;
    color: #FFFFFF;
    box-shadow: 0px 0px 0px 2px rgba(65, 100, 147, 0.25);
    transition: box-shadow 240ms;
}

button:focus {
    outline: none;
}

button:disabled {
    cursor: default;
    color: #CCCCCC;
}

button:disabled:hover {
    cursor: default;
    color: #CCCCCC;
}

button:disabled:active {
    box-shadow: none;
    transition: none;
}


/* Text Field */
input[type=text] {
    color: #383838;
    font-size: 14px;
    padding: 1px 0px;
    line-height: 22px;
    border: none;
    border-bottom: 2px solid #cedaeb;
    background-color: transparent;
}

input[type=text]:focus {
    outline: none;
    border-bottom: 2px solid #3a6ba1;
}

/* Password Field */
input[type=password] {
    color: #3a6ba1;
    font-size: 14px;
    padding: 0px;
    line-height: 22px;
    border: none;
    border-bottom: 2px solid #cedaeb;
    font-size: 14px;
}

input[type=password]:focus {
    outline: none;
    border-bottom: 2px solid #3a6ba1;
    background-color: transparent;
}

/* Select Dropdown */
select {
    min-width: 45px;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: listbox;
    font-size: 14px;
    color: #333333;
    padding: 0px;
    line-height: 22px;
    vertical-align: middle;
    padding-right: 16px;
    border: none;
    border-bottom: 2px solid #cedaeb;
    background-color: transparent;
    cursor: pointer;
    white-space: nowrap !important;
    border-radius: 0px !important;
}

select:focus {
    outline: none;
    border-bottom: 2px solid #3a6ba1;
}

/* Check Boxes */
input[type=checkbox] {
    display: none;
}

input[type=checkbox] + label {
    font-size: 15px;
    color: #337bca;
    padding: 0px;
    line-height: 22px;
    vertical-align: middle;
    display: inline-block;
    margin-right: 5px;
    cursor: pointer;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

input[type=checkbox] + label:before {
    font-family: FontAwesome;
    content: "\f096";
    width: 20px;
    display: inline-block;
    font-size: 18px;
    vertical-align: middle;
    line-height: 22px;
}

input[type=checkbox]:checked + label:before {
    font-family: FontAwesome;
    content: "\f046";
    width: 20px;
    display: inline-block;
    font-size: 18px;
    vertical-align: middle;
    line-height: 22px;
}

#notificationsCheck, #showVcunCheck, #displayVcuCheck, #enableRCcheck {
    margin: 10px 5px 14px 0px !important;
}

#notificationsCheck label, #showVcunCheck label, #displayVcuCheck label, #enableRCcheck label {
    word-break: normal !important;
    white-space: normal !important;
    margin-bottom: 16px;
}

/* Radio Boxes */
input[type=radio] {
    display: none;
}

input[type=radio] + label {
    color: #3a6ba1;
    padding-top: 5px;
    padding-bottom: 5px;
    vertical-align: middle;
    display: inline-block;
    cursor: pointer;
    margin-right: 5px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

input[type=radio] + label:before {
    font-family: FontAwesome;
    content: "\f10c";
    margin-right: 3px;
    font-size: 16px;
    vertical-align: middle;
}

input[type=radio]:checked + label:before {
    font-family: FontAwesome;
    content: "\f192";
    margin-right: 3px;
    font-size: 16px;
    vertical-align: middle;
}

.pill-nav {
    display: inline-block;
    color: black;
    text-align: center;
    font-size: 16px;
    border-bottom: 1px solid #3a6ba1;
    border-radius: 3px;
    font-size: 0;
    vertical-align: middle;
    white-space: nowrap;
    line-height: initial;
    margin-top: 10px;
}

.pill-nav input[type=radio]{
    display:none;
}

.pill-nav .radio_pill{
    cursor: pointer;
    font-size: 14px;
}

.pill-nav input[type=radio] + label {
    color: #3a6ba1;
    padding-left: 7px;
    padding-right: 7px;
    padding-top: 2px;
    padding-bottom: 2px;
    vertical-align: middle;
    display: inline-block;
    cursor: pointer;
    margin-right: 0px;
}

.pill-nav input[type=radio] + label:before {
    font-family: initial !important;
    content:  initial !important;
    margin-right: initial !important;
    font-size:  initial !important;
    vertical-align:  initial !important;
}

.pill-nav input[type=radio]:checked + label {
//    background-color: #3a6ba1;
    background-color: #457CC4;
    color: white;
}

.pill-nav input[type=radio]:checked + label:before {
    font-family: initial !important;
    content: initial !important;
    margin-right: initial !important;
    font-size: initial !important;
    vertical-align:  initial !important;
}

.pill-nav button:disabled {
    cursor: default;
    color: #666666;
    background-color: #333333;
}
.pill-nav button {
    border: none;
    margin: 0px;
    border-radius: 2px;
}


/* CSS_dhtmlxTemplateImportant */
/* =========================== */
div.gridbox_material.gridbox {
    border-radius: 5px !important;
    border: 1px solid #9cb5d7 !important;
}

div.gridbox_material.gridbox .xhdr {
    border-bottom: 1px solid #97b2d7 !important;
}

div.gridbox_material.gridbox table.hdr tr {
    background-color: none !important;
    border: none !important;
}

div.gridbox_material.gridbox table.hdr td {
    background-color: #9cb5d7 !important;
    border: 1px solid transparent !important;
    color: #ffffff !important;
    font-size: 14px !important;
    border-right: 1px solid transparent !important;
}

div.gridbox_material.gridbox table.hdr td:hover {
    border-right: 1px solid #839fc5 !important;
}

div.gridbox_material.gridbox table.obj.row20px tr td {
    border-right: 1px solid transparent !important;
}

div.gridbox_material.gridbox table.hdr td.dhxgrid_sort_desc_col {
    background-image: none !important;
}

div.gridbox_material.gridbox table.hdr td.dhxgrid_sort_desc_col::before {
    content: "\f0dd";
    font-family: FontAwesome;
    width: 13px;
    height: 13px;
    position: absolute;
}

div.gridbox_material.gridbox table.hdr td.dhxgrid_sort_asc_col {
    background-image: none !important;
}

div.gridbox_material.gridbox table.hdr td.dhxgrid_sort_asc_col::before {
    content: "\f0de";
    font-family: FontAwesome;
    width: 13px;
    height: 13px;
    position: absolute;
}

div.gridbox_material.gridbox table.obj.row20px tr.rowselected td {
    background-color: #ffebc1 !important;
}

div.gridbox_material.gridbox table.obj tr.rowselected td:first-child {
    border-left: 2px solid #db9f20 !important;
}

.dhtmlxcalendar_material div.dhtmlxcalendar_dates_cont ul.dhtmlxcalendar_line li.dhtmlxcalendar_cell_month_date {
    background-color: #3a6ba1;
}

.dhtmlxcalendar_material div.dhtmlxcalendar_dates_cont ul.dhtmlxcalendar_line li.dhtmlxcalendar_cell_month_date_hover {
    background-color: #3a6ba1;
}

div.dhx_popup_material div.dhx_popup_area {
    border-radius: 5px;
}

/* CSS_Phone */
/* ========= */
.noneSelected {
    text-align: center;
    padding: 25px
}

.Settings_VolumeOutput_Container{
    display: inline-block;
    width: 100%;
    height: 4px;
    border-radius: 50px;
    border: 1px solid #CCCCCC;
    margin-top: 10px;
    background-color: #FFFFFF;
    box-shadow: inset 1px 1px 3px rgba(0, 0, 0, 0.2);
}

.Settings_VolumeOutput{
    width: 5%;
    height: 4px;
    border-radius: 50px;
    background-color: rgb(14, 192, 23);
    box-shadow: inset 2px 2px 3px rgba(255, 255, 255, 0.2), inset -2px -2px 3px rgba(0, 0, 0, 0.2);
}

.clearsearchTextBtn {
    border-radius: 100px;
    cursor: pointer;
    width: 16px;
    height: 16px;
    border: none;
    background-color: transparent;
    padding: 0px;
    font-size: 13px;
    box-shadow: none;
    color: #333333;
    min-width: 0px;
    line-height: 16px
}

.clearsearchTextBtn:before {
    content: "\f05c";
    font-family: FontAwesome;
}

.clearsearchTextBtn:hover {
    background-color: transparent;
}

.clearsearchTextBtn:active {
    background-color: transparent;
}

.cleanScroller{
    /* Firefox */
    scrollbar-width: thin;
    scrollbar-color: #a6a6a6 transparent;
}

.cleanScroller::-webkit-scrollbar {
    width: 10px;
}

.cleanScroller::-webkit-scrollbar-thumb {
    background: #a6a6a6;
    border-radius: 5px;
}

.cleanScroller::-webkit-scrollbar-track {
    background: transparent;
}

.contactArea {
    height: 100%;
    overflow-y: auto;
    overflow-x: hidden;
    scrollbar-color: #79a0d4 #eaeeff;
    /* For Firefox */
    position: absolute;
    top:0;
    left:0;
    width:100%;
    z-index: 1;
    padding: 5px;
    box-sizing: border-box;
}

#totalNmbrContacts {
    display: block;
    position: relative;
    width:100%;
    height: auto;
    margin: 0px;
    padding: 3px 10px;
    font-size: 12px;
    color: #404040;
    background-color: #ffffff;
}
.buddy {
    padding: 8px;
    height: 44px;
    cursor: pointer;
    color: #333333;
    border-left: 3px solid transparent;
    position: relative;
}

.buddy:hover {
    background-color: #edf4fc;
}

.buddy:hover .contactDate {
    display: block;
}

.buddySelected {
    padding: 8px;
    height: 44px;
    cursor: pointer;
    color: #333333;
    background-color: #e3f1ff;
    position: relative;
    border-left: 2px solid #5f97cf;
}

.buddySelected:hover .contactDate {
    display: block;
}

.buddyActiveCall {
    padding: 5px;
    height: 43px;
    cursor: pointer;
    color: #333333;
    background-color: #E6F1FF;
    position: relative;
    border-left: 3px solid #4E8ED5;
}

.buddyActiveCallHollding {
    padding: 5px;
    height: 38px;
    cursor: pointer;
    color: #333333;
    background-color: #E6F1FF;
    position: relative;
    border-left: 3px solid #4E8ED5;
}

.lineIcon {
    border-radius: 50px;
    width: 36px;
    height: 36px;
    background-color: #4e8ed5;
    box-shadow: 1px 1px 5px rgba(0,0,0,0.25);
    float: left;
    text-align: center;
    line-height: 36px;
    padding: 0px;
    margin: 4px 0px 0px 4px;
    font-size: 24px;
    color: #F3F3F3;
}

.streamSctnRightTop {
    float: left;
    height: 38px;
    line-height: 38px;
    padding: 5px;
    margin: 6px 0px 0px 6px;
}

.streamSectionRight .lineIcon {
    margin: 5px 0px 0px 4px;
}

.buddyIcon {
    border-radius: 50px;
    width: 39px;
    height: 39px;
    margin: 2px 0px 0px 0px;
    background-size: 39px;
    background-repeat: no-repeat;
    box-shadow: 1px 1px 2px rgba(0,0,0,0.25);
    float: left;
}
.contact .buddyIcon {
    margin: 4px 0px 0px 0px !important;
}

.callAnswerBuddyIcon {
    border-radius: 100px;
    width: 100px;
    height: 100px;
    background-size: 100px;
    background-color: #CCCCCC;
    border: 1px solid #3e3e3e;
    display: inline-block;
}

.profileContainer {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    z-index: 1;
}

.contact {
    padding: 6.2px 5px 0px 5px;
    color: #4c4c4c;
    position: relative;
    cursor: pointer;
}

.contactNameText {
    margin-left: 50px;
//    margin-top: 3px;
    margin-top: 4px;
    font-size: 14px;
    color: #363636;
    margin-right: 55px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

#myContacts .contactNameText { 
    margin-top: 2px !important;
    width: 232px !important;
}

.contactDate {
    display: none;
    float: right;
    font-size: 11px;
    color: #3f3f3f;
    margin-top: 6px;
}

.presenceText {
    height: 20px;
    margin: 1px 7px 0px 50px; 
    font-size: 12px;
    color: #4f4f4f;
    white-space: nowrap;
    overflow: hidden;
    scrollbar-color: #79a0d4 #eaeeff;
}

.buddy .presenceText {
    height: 28px;
}
.buddySelected .presenceText {
    height: 28px;
}

#UserProfile .presenceText {
    padding: 2px 0px 10px 0px !important;
}

.searchClean {
    display: inline-block;
    margin: 2px 0px 0px 0px;
    padding: 0px 1px 0px 5px;
    background-color: #fafafa;
    height: 26px;
    border: 0;
    border-radius: 3px;
    box-sizing: border-box;
    color: #5a5a5a;
}

.searchClean:before {
    content: "\f002";
    font-family: FontAwesome;
    color: #393f47;
    text-shadow: 1px 1px 5px rgba(0, 0, 0, 0.25);
}

.searchClean INPUT {
    border: none;
    margin-left: 5px;
    outline: none;
    background-color: transparent;
}

.searchClean INPUT:focus {
    border: none;
}

.answerCall {
    text-align: center;
    padding: 25px;
}

.dialCall {
    text-align: center;
    padding: 25px;
    margin-top: 10px;
}

.progressCall {
    text-align: center;
    padding: 25px;
    margin-top: 10px;
}

.videoCall {
    margin-top: 10px;
}

.stream {
    display: none;
}

#contactTopSection {
    padding: 0px;
    border-top: 6px solid #f0f5fc;
    border-left: 6px solid #f0f5fc;
    border-right: 6px solid #f0f5fc;
    border-radius: 0px !important;
}

#chatTextPanel {
    padding: 6px !important;
    border-top: 6px solid #f0f5fc;
    border-left: 6px solid #f0f5fc;
    border-right: 6px solid #f0f5fc;
    border-radius: 0px !important;
}

#sendChatMessageSection {
    padding: 6px !important;
    border-top: 6px solid #f0f5fc;
    border-left: 6px solid #f0f5fc;
    border-right: 6px solid #f0f5fc;
    border-bottom: 6px solid #f0f5fc !important;
    border-radius: 0px !important;
}

.streamSelected {
    height: 100%;
    width: 100%;
}

.streamSection {
    position: relative;
    background-color: #fafafa;
    vertical-align: top;
}

.streamSectionRight {
    position: relative;
    height: 200px;
    background-color: #fafafa;
    vertical-align: top;
}

#searchBoxAndIcons {
    display: block;
    margin: 0px 0px 0px 5px;
    width: 100%;
}

.streamSectionBackground, .logoSectionBackground {
    background-position-x: center;
    background-position-y: bottom;
}

.chatHistory {
    display: block;
    position: absolute;
    user-select: none;
    top: 0px;
    left: 0px;
    bottom: 0px;
    width: 100%;
    height: 100%;
    z-index: 1;
    box-sizing: border-box;
    overflow: auto;
    padding: 5px;
}
.roundButtons {
    border-radius: 100px;
    cursor: pointer;
    width: 32px;
    height: 32px;
    line-height: 32px;
    border: 1px solid #B3B3B3;
    background-color: transparent;
    padding: 0px;
    font-size: 16px;
    box-shadow: none;
    color: #5f5f5f;
    min-width: 0px;
}

.roundButtonsSpec, .roundButtonsSpecTC {
    border-radius: 100px;
    cursor: pointer;
    width: 32px;
    height: 32px;
    line-height: 32px;
    border: 1px solid #B3B3B3;
    background-color: transparent;
    padding: 0px;
    font-size: 16px;
    box-shadow: none;
    color: #5f5f5f;
    min-width: 0px;
    margin: 2px 0px 4px 2px;
}

.roundButtons:hover, .roundButtonsSpec:hover, .roundButtonsSpecTC:hover {
    border: 1px solid #404040;
    background-color: #333333;
}

.roundButtons:active, .roundButtonsSpec:active, .roundButtonsSpecTC:active {
    border: 1px solid #404040;
    background-color: #222222;
    color: #FFFFFF;
}

.toolBarButtons {
    border-radius: 5px;
    cursor: pointer;
    width: 26px;
    height: 26px;
    border: 1px solid #CCCCCC;
    background-color: #ececec;
    padding: 0px;
    font-size: 14px;
    box-shadow: none;
    color: #333333;
    min-width: 0px;
    vertical-align: middle;
}

.toolBarButtons:hover {
    border: 1px solid #CCCCCC;
    background-color: #CCCCCC;
}

.toolBarButtons:active {
    border: 1px solid #666666;
    background-color: #666666;
    color: #FFFFFF;
}

.meterContainer {
    display: inline-block;
    width: 5px;
    height: 28px;
    border: 1px solid #CCCCCC;
    background-color: #ececec;
    padding: 0px;
    vertical-align: middle;
    position: relative;
    border-radius: 3px;
}

.meterLevel {
    background-color: #19ad19;
    width: 100%;
    position: absolute;
    left: 0px;
    bottom: 0px;
    border-radius: 2px;
}

.EmojiMenu {
    position: absolute;
    width: 320px;
    height: auto;
    bottom: 140px;
    right: 12px;
    background-color: #ffffff;
    border-radius: 4px;
    box-shadow: 0 0 7px rgba(0, 0, 0, 0.1);
    z-index: 30;
}

.sendMessagePreview {
    padding-top: 2px;
    padding-bottom: 2px;
    border-bottom: 2px solid #cecece;
    font-family: Inter, sans-serif;
    font-size: 14px;
    color: #272f39;
}

.sendMessagePreviewLeft {
    margin-right: 30px;
}

.sendMessagePreviewHtml {
    background-color: rgba(215, 232, 247, 0.8);
    padding: 5px;
    box-sizing: border-box;
    border-radius: 5px;
    display: inline-block;
    text-align: left;
    max-height: 300px;
    max-width: 85%;
    overflow-y: auto;
    overflow-x: hidden;
    color: #383838;
}

.previewImage {
    cursor: pointer;
    max-width: 320px;
    border-radius: 5px;
    border: 1px solid #929292;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, 0.25);
}

.previewHyperlink {
    color: #1157a0 !important;
}

.sendMessagePreviewContainer{
    width: 100%;
}

.sendMessagePreviewContainer TD {
    vertical-align: middle;
    text-align: center;
}

.sendMessageContainer {
    width: 100%;
    height: 80px;
}

.sendMessageContainer TD {
    vertical-align: top;
    text-align: center;
}

.chatMessage {
    box-sizing: border-box;
    padding: 6px;
    width: 100%;
    height: 118px;
    border: none;
    outline: none;
    resize: none;
    font-family: Inter, sans-serif;
    font-size: 15px;
    color: #4e4e4e;
    background-color: transparent;
}

.buddyIconSmall {
    display: block;
    border-radius: 50px;
    width: 18px;
    height: 18px;
    background-size: 18px;
    background-color: #CCCCCC;
    border: 1px solid #FFFFFF;
    box-shadow: 1px 1px 3px rgba(0,0,0,0.25);
}

.theirChatMessage {
    margin-left: 5px;
    margin-top: 9px;
    margin-bottom: 9px;
    margin-right: auto;
    max-width: 85%;
}

.theirChatMessage td {
    padding: 6px 13px;
    vertical-align: top;
    text-align: left;
}

.theirChatMessage.recFileChatDown td {
    padding: 0px !important;
    vertical-align: top;
    text-align: left;  
}

.theirChatMessageText {
    display: inline-block;
    background-color: #e7f9f1;
    padding: 5px;
    border-radius: 5px;
    font-size: 14px;
    color: #272f39;
    position: relative;
}

.ourChatMessage {
    margin-right: 5px;
    margin-top: 9px;
    margin-bottom: 9px;
    margin-left: auto;
    max-width: 85%;
}

.ourChatMessage td {
    padding: 6px 13px;
    vertical-align: top;
    text-align: left;
}
.ourChatMessage.sentFileChatDown td {
    padding: 0px !important;
    vertical-align: top;
    text-align: left;
}

.ourChatMessageText {
    display: inline-block;
    background-color: #e9f4ff;
    padding: 5px;
    border-radius: 5px;
    font-size: 14px;
    color: #272f39;
    position: relative;
}

.messageText {
    display: inline;
    user-select: text;
    cursor: text;
    font-size: 15px;
    word-break: keep-all;
    white-space: pre-wrap;
}

.chatMessageTable {
    position: relative;
    z-index: 1020;
}

.chatMessageDropdown {
    cursor: pointer;
    position: absolute;
    right: 5px;
    width: 20px;
    height: 20px;
    line-height: 20px;
    text-align: center;
    background-color: rgba(255, 255, 255, 0.8);
    border-radius: 50px;
}

.callRecordings {
    font-size:11px
}

.callRecordings button {
    width: 30px;
    text-align: center;
    height: 30px;
    line-height: 30px;
    float: left;
    margin-right: 10px;
    color: #333333;
    background-color: #CCCCCC;
    border: 1px solid #222222;
    border-radius: 50px;
}

.callRecordings button:hover {
    color: #cccccc;
    background-color: #333333;
    border: 1px solid #222222;
}

.callRecordings img {
    width: 100%;
    max-width: 400px; /* 854x480 (16:9) */
    border-radius: 5px;
    filter: blur(1px);
    transform: scale(1.1);
}

.callRecording {
    background-color: #CCCCCC;
    border-radius: 10px;
    padding: 5px;
    margin-top: 2px;
    margin-bottom: 2px;
}

.callRecording DIV {
    overflow: hidden;
    border-radius: 5px;
}

.videoPoster {
    border-radius: 50px !important;
    margin: 0px !important;
    border: none !important;
    color: #cccccc !important;
    background-color: rgba(0, 0, 0, 0.5) !important;
    width: 50px !important;
    height: 50px !important;
    padding: 0px !important;
    position: absolute;
    left: calc(50% - 25px);
    top: calc(50% - 25px);
}

.videoPoster:hover {
    color: #e0e0e0 !important;
}

.videoPoster I {
    border: 1px solid #cccccc;
    border-radius: 50px;
    width: 48px;
    text-align: center;
    height: 48px;
    line-height: 48px;
    font-size: 24px;
    background-color: rgba(0, 0, 0, 0.5);
}

.previewVideo {
    max-height: 720px;
    max-width: 100%;
    background-color: #666666;
    border: 1px solid #222222;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, .25);
    border-radius: 5px;
    transform: rotateY(180deg);  
}

.emojiButton button {
    font-size: 23px;
    padding-left: 0px;
    padding-right: 0px;
    min-width: 30px;
    min-height: 30px;
    line-height: 28px;
    text-align: center;
}

.PreviewContainer {
    text-align: left;
    margin-top: 15px;
    position: absolute;
    left: 0px;
    right: 0px;
    z-index: 10;
}

.PreviewContainer VIDEO {
    margin-left: 10px;
    border-radius: 5px;
    background-color: #000000;
    height: auto;
    width: 15%;
}

.PreviewContainer_FS {
    height: calc(10%);
    position: absolute;
}

.PreviewContainer_FS VIDEO {
    height: 100% !important;
    width: auto !important;
}

.StageContainer {
    width: 100%;
    min-height: 360px;
    background-color: #000000;
    margin-top: 10px;
    text-align: center;
    z-index: 9;
}

.StageContainer VIDEO {
    border-radius: 0px;
    background-color: #000000;
    height: auto;
    max-height: 360px;
    width: 100%;
    max-width: 898px;
    object-fit: contain;
}

.StageContainer_FS {
    height: calc(100% - 55px) !important;
    max-height: initial !important;
}

.StageContainer_FS VIDEO {
    height: 100% !important;
    width: 100% !important;
    max-height: 100% !important;
    max-width: 100% !important;
    object-fit: cover;
}

.canvas-container {
    display: inline-block;
}

.callStatus {
    display: block;
    margin: 10px 0px 0px 0px;
    background-color: #EBF3FC;
    border-radius: 50px;
    padding: 4px 0px 3px 15px;
    text-align: left;
    color: #383838;
    font-size: 15px !important;
}
#contactTopSection .callStatus {
    margin: 60px 0px 0px 0px;
}
.answerButton {
    background-color: #059609;
    border: none;
    padding: 4px 15px 7px 15px;
    font-weight: 500;
    color: #ffffff;
    cursor: pointer;
}

.answerButtonVid {
    background-color: #059609;
    border: none;
    padding: 6.5px 15px 7.5px 15px;
    font-weight: 500;
    color: #ffffff;
    cursor: pointer;
}

.answerButton:hover, .answerButtonVid:hover {
    background-color: #0aa80f;
    border: none;
}

.answerButton:active, .answerButtonVid:active {
    background-color: #017a05;
}

.hangupButton {
    background-color: #dc0000;
    padding: 4px 15px 7px 15px;
    font-weight: 500;
    border: none;
    color: #ffffff;
    cursor: pointer;
}

.streamSection .hangupButton {
    margin-top: 6px;
}

.hangupButton:hover {
    background-color: #ff1b1b;
    border: none;
}

.hangupButton:active {
    background-color: #d80000;
}

.dotOnline {
    background-color: #3fbd3f;
    border: 1px solid #3fbd3f;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotOffline {
    background-color: #b5b5b5;
    border: 1px solid #808080;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotRinging {
    background-color: #3fbd3f;
    border: 1px solid #148014;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotRinging:before {
    content: "\f2a0";
    font-family: FontAwesome;
    position: absolute;
    left: 2.5px;
    top: 0px;
}

.dotInUse {
    background-color: #3fbd3f;
    border: 1px solid #148014;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotInUse:before {
    content: "\f095";
    font-family: FontAwesome;
    position: absolute;
    left: 2.5px;
    top: -2.5px;
}

.dotDoNotDisturb {
    background-color: #ff6600;
    border: 1px solid #ff6600;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotCustom {
    background-color: #b949e2;
    border: 1px solid #b949e2;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotReady {
    background-color: #3fbd3f;
    border: 1px solid #148014;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotOnHold {
    background-color: #3fbd3f;
    border: 1px solid #148014;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotOnHold:before {
    content: "\f095";
    font-family: FontAwesome;
    position: absolute;
    left: 2.5px;
    top: -2.5px;
    color: #CCCCCC;
}

.dotFailed {
    background-color: red;
    border: 1px solid darkred;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotAway {
    background-color: #05a3d6;
    border: 1px solid #05a3d6;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotAutoAnswer {
    background-color: #4ef6bf;
    border: 1px solid #4ef6bf;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 33px;
    top: 36px;
    font-size: 13px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.missedNotifyer {
    background-color: #ec2121;
    border: 2px solid #ec2121;
    position: absolute;
    width: 23px;
    height: 23px;
    line-height: 23px;
    font-weight: bold;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    top: 4px;
    right: 2.5px;
    font-size: 14px;
    text-align: center;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
}

#quickDialSection {
    display: block;
    position: absolute;
    float: right;
    top: 4px;
    right: 30px;
}

.quickDial {
    position: relative;
    display: inline-block;
    border-radius: 100px;
    cursor: pointer;
    width: 18px;
    height: 18px;
    line-height: 18px;
    text-align: center;
    background-color: #3f61a7;
    border: 1px solid #3f61a7;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    padding: 1.7px 3px 3px 3px;
    margin: 0px 2px 0px 0px;
    font-size: 16px;
    color: #fafafafa;
    min-width: 0px;
}

.quickDial:hover {
    color: #dcdcdc !important;
    background-color: #365596;
    border: 1px solid #365596;
}

.startDragDrop {
    outline: 2px dashed #184369;
}

.progressBarContainer {
    border: 1px solid #787878;
    width: 250px;
    height: 10px;
    background-color: #fafafa;
    box-shadow: inset 0px 0px 3px rgba(0, 0, 0, 0.5);
    border-radius: 5px;
    margin-top: 5px;
    overflow: hidden;
}

.progressBarTrack {
    background-color: #19cc19;
    width: 0%;
    height: 10px;
    box-shadow: inset 3px 3px 5px rgba(255, 255, 255, 0.5);
}

.audioStats {
    padding:10px;
    overflow: auto;
    position: fixed;
    top: 0px;
    left: 0px;
    width: 100%;
    box-sizing: border-box;
    height: 100%;
    background-color: #222222;
    z-index: 99999999;
}

.audioStatsSet {
    max-width: 1240px;
    margin-left: auto;
    margin-right: auto;
}

.audioGraph {
    background-color: #FFFFFF;
    border-radius: 5px;
    margin-top: 10px;
    margin-left: auto;
    margin-right: auto;
}

.buddyProfilePic {
    display: block;
    width: 150px;
    height: 150px;
    border: 10px solid #FFFFFF;
    border-radius: 200px;
    margin-left: auto;
    margin-right: auto;
    background-size: cover;
    background-position: center;
    margin-top: 10px;
    background-color: #F3F3F3;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, 0.2);
}

.ProfileTextLarge {
    font-size: 22px;
    color: #4c4c4c;
    line-height: 22px;
}

.ProfileTextMedium {
    font-size: 14px;
    color: #4c4c4c;
    line-height: 16px;
    word-wrap: break-word;
}

.ProfileTextSmall {
    font-size: 12px;
    color: #4c4c4c;
    line-height: 12px;
}

#ProfileInfo {
   text-align: center;
   margin: 0px 0px 8px 0px;
}

.ConferenceParticipant {
    border: 1px solid #CCCCCC;
    background-color: #FFFFFF;
    border-radius: 100px;
    display: inline-block;
    margin-right: 10px;
    margin-bottom: 10px;
    width: 240px;
    padding: 10px;
    box-sizing: content-box;
    vertical-align: top;
    height: 37px;
    font-size: 14px;
    color: #4c4c4c;
    cursor: pointer;
    box-shadow: 1px 1px 5px rgba(0,0,0,0.15);
}

.ConferenceParticipant .Talking {
    border: 3px solid green;
    border-radius: 50px;
    width: 32px;
    height: 32px;
    background-size: 32px;
    background-color: #CCCCCC;
    box-shadow: 1px 1px 5px rgba(0,255,0,0.25);
    float: left;
    margin-right: 10px;
}

.ConferenceParticipant .NotTalking {
    border: 3px solid white;
    border-radius: 50px;
    width: 32px;
    height: 32px;
    background-size: 32px;
    background-color: #CCCCCC;
    box-shadow: 1px 1px 5px rgba(0,0,0,0.25);
    float: left;
    margin-right: 10px;
}

.FlagCall {
    color: orange;
    font-size: 18px;
    vertical-align: text-top;
    text-shadow: 1px 1px 2px rgba(0, 0, 0, 0.25);
}

.SentMessage {
    color: #0099c7;
    font-size: 13px;
    margin-left: 6px;
}

.FailedMessage {
    color: #c7000f;
    font-size: 15px;
    margin-left: 5px;
}

/* Tags */
.tags {
    list-style: none;
    margin: 0;
    padding: 0;
    display: inline-block;
    vertical-align: middle;
}

.tags li {
    user-select: none;
    float: left;
    margin-bottom: 1px;
    margin-top: 1px;
    margin-left: 0px;
    margin-right: 2px;
    color: #333333;
    border: 1px solid #888888;
    background-color: rgba(255, 255, 255, 0.25);
    border-radius: 6px;
    padding: 0px;
    padding-left: 2px;
    padding-right: 5px;
    line-height: 18px;
    font-size: 12px;
    cursor: pointer;
}

.tags li:hover::before {
    content: "\f1f8";
}

.tags li::before {
    content: "\f02b";
    font-family: FontAwesome;
    width: 16px;
    display: inline-block;
    line-height: 16px;
    height: 16px;
    vertical-align: middle;
    text-align: center;
}

.tags input[type=text] {
    font-size: 12px;
    padding: 0px;
    margin: 0px;
    line-height: initial;
    color: #333333;
    border: none;
    width: 60px;
}

.tags .tagText:hover::before {
    content: "\f02b";
}

.tags .tagText::before {
    content: "\f02b";
}

.cdrTag {
    margin-right: 10px;
}

.cdrTag::before {
    content: "\f02b";
    font-family: FontAwesome;
    width: 16px;
    display: inline-block;
    line-height: 16px;
    height: 16px;
    vertical-align: middle;
    text-align: center;
}

.messageReadMore {
    text-align: left;
    font-size: 12px;
}

.messageReadMore span {
    text-decoration: underline;
    color: #0061c7;
    cursor: pointer;
}

.cdrComment {
    font-size: 12px !important;
    color: #444444 !important;
    line-height: initial !important;
    text-align: left;
}

.cdrComment input[type=text] {
    font-size: 12px !important;
    color: #444444 !important;
    background-color: #FFFFFF;
    border: none !important;
    line-height: initial !important;
    box-sizing: border-box;
    width:100%;
    border-radius: 3px;
    padding: 3px;
}

.inCallButtons {
    width: 45px !important;
    height: 45px !important;
    font-size: 20px !important;
    margin-left: 2px !important;
    margin-right: 2px !important;
    padding-left: 0px !important;
    padding-right: 0px !important;
}

#selectFromNbDial {
    width: auto;
    min-width: 82%;
    padding: 0px 6px;
    font-size: 16px;
    text-align: center;
    border-radius: 10px !important;
    border: 0.01em solid;
    border-color: #989898;
    background-color: transparent;
}

/* .dialTextInput { */

#dialText {
    width: 168px;
    font-size: 16px;
    text-align: center;
    border-radius: 10px;
    border: 0.01em solid;
    border-color:#989898;
    background-color: transparent;
}

#dialText:focus {
    outline: none;
}

.dialButtons {
    font-size: 24px; 
    border: none;
    color: #333333;
}

.dialButtons:hover {
    color: #f3f3f3;
    background-color: #333333;
}

.dialButtons:disabled {
    color: #666666;
}

.dialButtons:disabled:hover {
    color: #666666;
    background-color: transparent;
    border: none;
}

.timelineMessage {
    margin-left: 20%;
    color: #F3F3F3;
    border-left: 3px solid #3c5e82;
}

.timelineMessageDot {
    position: relative;
    left: -6.5px;
    color: #3c5e82;
}

.timelineMessageArea {
    color: #F3F3F3;
    padding-top: 10px;
    padding-bottom: 10px;
    padding-left: 0px;
}

.timelineMessageDate {
    color: #565656;
    font-size: 12px;
}

.timelineMessageText {
    color: #565656;
    padding: 5px;
    background-color: #ebf4ff;
    border-radius: 10px;
    margin-left: 10px;
}

#smallLogo {
    display: inline-block;
    position: absolute;
//    margin: 2px 0px 0px 0px;
    margin: 6px 0px 0px 0px;
}

#aboutImg {
    display: inline-block;
    background-image: url('../images/open-book.svg');
    background-repeat: no-repeat;
    width: 20px;
    height: 18px;
    margin: 0px 10.5px 7.5px 0px;
}

#aboutImg:hover {
    background-image: url('../images/open-book-dark.svg');
    background-repeat: no-repeat;
    cursor: pointer;
}

#BtnFreeDial {
    display: inline-block;
    width: 20px;
    height: 20px;
    background-image: url('../images/dialpad.svg');
    background-repeat: no-repeat;
    vertical-align: top;
    margin-right: 2px;
}

#BtnFreeDial:hover {
    background-image: url('../images/dialpad-white.svg');
    background-repeat: no-repeat;
}
#collapseLeftPanel {
    display: inline-block;
    background-image: url('../images/collapse.svg');
    background-repeat: no-repeat;
    cursor: pointer;
    width: 14px;
    height: 26px;
    margin: 15px 2px 1px 0px;
}

#collapseLeftPanel:hover {
    background-image: url('../images/collapse-dark.svg');
    background-repeat: no-repeat;
    cursor: pointer;
    width: 14px;
    height: 26px;
    margin: 15px 2px 1px 0px;
}

#ButtonsOnSearchLine {
    display: block;
    position: relative;
    float: right;
    margin: 0px 13px 0px 0px;
}

.fa-columns {
    cursor: pointer;
    font-size: 15.5px !important;
}

.fa-columns:hover {
    color: #626262;
}

.fa-phone {
    font-size: 16px;
    padding-top: 1px;
}

.fa-video-camera {
    font-size: 14px;
}

.fa-wifi {
    padding-top: 3px;
    font-size: 12px !important;
}

#dialAudio .fa-phone {
    padding: 0px 0px 4px 0px;
    font-size: 20px;
}    

#dialVideo .fa-video-camera {
   padding: 0px 0px 8px 0px;
   font-size: 16px;
}

#contactTopSection .roundButtons .fa {
   display: block;
   font-size: 15px;
}

.callRecordings .callRecording .fa-play {
   display: block;
   padding: 0px 0px 0px 1px;
}

#LaunchConferences {
    display: inline-block;
    vertical-align: top;
    margin: 0px 2px 5px 5px;
    padding: 0px 1.5px 0px 1.5px;
}

#LaunchConferences .fa-users {
    font-size: 18px !important;
    color: #626262;
}

#LaunchConferences .fa-users:hover {
    color: #ffffff;
}

#BtnSettings {
    display: inline-block;
    vertical-align: top;
    margin: 0px 1px 5px 4px;
    padding: 0px 2.5px 0px 2.5px;
}

.fa-cog {
    font-size: 20px !important;
    color: #626262;
}

.fa-cog:hover {
    color: #ffffff;
}

.fa-chevron-left {
    padding-right: 3px;
}

.fa-chevron-down {
    padding-top: 2px;
}

.fa-ellipsis-h {
    padding-top: 1.5px;
}

#inLogoSection {
    display: block;
    position: relative;
    float: right;
    margin: 0px;
    padding: 0px;
    z-index: 20;
}

#smsInLogoSection {
    display: none;
    color: #626262;
    cursor: pointer;
    font-size: 19px;
    margin: 9.7px 11px 0px 0px;
    vertical-align: top;
}

#emailInLogoSection {
    display: inline-block;
    color: #626262;
    cursor: pointer;
    margin: 14px 11px 0px 0px;
    vertical-align: top;
}

#faxInLogoSection {
    display: none;
    color: #626262;
    cursor: pointer;
    font-size: 17px;
    margin: 11px 11px 0px 0px;
    vertical-align: top;
}

#aboutInLogoSection {
    display: inline-block;
}
#shrinkLeftPanel {
    display: inline-block;
}
#emailInLogoSection .fa-envelope-o {
    font-size: 19px;
}
#smsInLogoSection .fa-commenting-o:hover, #faxInLogoSection .fa-fax:hover, #emailInLogoSection .fa-envelope-o:hover {
    color: #0f44b1;
}
.fa-pencil-square-o {
    display: none;
}

.buddyIcon:hover .fa-pencil-square-o {
    display: block;
    position: relative;
    margin-left: -5px;
}

#AboutLogoImg {
    display: block;
    margin: 16px auto 22px auto;
    width: 270px;
    height: auto;
}

.copyToClipboard {
    display: inline-block;
    margin: 2px 0px 0px -8px;
    color: #cccccc;
}

#ConfirmMessageText {
    margin: 12px 10px 10px 10px !important;
    font-size: 16.8px;
}

#preview_ringtone {
    margin: 8px 0px 0px 0px;
}

/* Modals */

#jg_popup_table.jg_popup_basic {
    background-color: #fff;
}
#jg_popup_overlay {
    z-index:2100;
}
#jg_popup_inner {
    z-index:2102;
}
.addContactPopup, .editContactPopup {
    padding-top: 20px;
    padding-bottom: 20px;
    overflow-y: auto !important;
    overflow-x: hidden !important;
    scrollbar-color: #516896 transparent;
}
#aboutPopup {
    display: block;
    position: relative;
    font-size: 16px !important;
    color: #333333 !important;
    width: 100% !important;
    height: auto;
}
#ok_button {
    display: block;
    padding: 7px 12px;
    margin: 14px auto 10px auto;
    font-size: 16px;
    color: #ffffff;
    background: #457CC4;
}
.ConfCloseAccount, .ConfDelExtConfData {
    padding: 20px 14px 18px 14px !important;
    line-height: 1.5;
}
.confirmDelContact {
    padding: 4px 5px 18px 5px !important;
    line-height: 1.5;
}
#bottomButtons, #ConfDelContact, #ConfCloseAccount {
    display: block;
    background: #ffffff;
    width: 100%;
    height: auto;
    text-align: center;
}
#ConfDelExtCnfInfo {
    display: block;
    margin: 0px 0px 9px 0px;
    background: #ffffff;
    width: 100%;
    height: auto;
    text-align: center;
}
#bottomButtonsConf {
    display: block;
    margin: 20px auto 0px auto;
    text-align: center;
}
#save_button_conf {
    display: inline-block;
    padding: 8px 12px;
    font-size: 15px;
    font-weight: 500;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 8px 10px 8px;
    border-radius: 4.5px;
}
@media (max-width: 555px) {
  #cancel_button_conf {
    display: inline-block;
    padding: 8px 12px;
    font-size: 15px;
    font-weight: 500;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 80px 10px 8px;
    border-radius: 4.5px;
  }
}
@media (min-width: 556px) {
  #cancel_button_conf {
    display: inline-block;
    padding: 8px 12px;
    font-size: 15px;
    font-weight: 500;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 208px 10px 8px;
    border-radius: 4.5px;
  }
}

@media (max-width: 625px) {
  #actionButtonsTop {
    display: block;
    position: relative;
    float: left !important;
    clear: both;
    margin: 10px 10px 6px 16px;
  }
}

@media (min-width: 626px) {
  #actionButtonsTop {
    display: block;
    position: relative;
    float: right;
    line-height:46px; 
    margin: 7.5px 7px 0px 0px;
  }
}
#save_button, #cancel_button {
    display: inline-block;
    padding: 7px 12px;
    font-size: 16px;
    font-weight: 500;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 8px 10px 8px;
    border-radius: 4.5px;
}
#ConfirmOkButton, #ConfirmCancelButton, #PromptOkButton, #PromptCancelButton, #AlertOkButton {
    display: inline-block;
    padding: 6px 11px;
    font-size: 15px;
    font-weight: 500;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 8px 10px 8px;
    border-radius: 4.5px;
}
#ConfirmDelEcdButton, #ConfirmExitButton {
    display: inline-block;
    padding: 8px 11px;
    font-size: 15px;
    font-weight: 500;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 8px 10px 8px;
    border-radius: 4.5px;
}
#ok_button:hover, #save_button:hover, #cancel_button:hover, #save_button_conf:hover, #cancel_button_conf:hover, #ConfirmOkButton:hover, #ConfirmCancelButton:hover, #PromptOkButton:hover, #PromptCancelButton:hover, #AlertOkButton:hover {
    background: #3367AB;
}
#ok_button:active, #save_button:active, #cancel_button:active, #save_button_conf:active, #cancel_button_conf:active, #ConfirmOkButton:active, #ConfirmCancelButton:active, #PromptOkButton:active, #PromptCancelButton:active, #AlertOkButton:active {
    background: #265694;
}
#jg_popup_content a {
    text-decoration: none;
    color: #1157a0 !important;
}

#jg_popup_table.jg_popup_basic #jg_popup_close {
    display: none !important;
}
#jg_popup_table.jg_popup_basic #jg_popup_title {
    height:auto; font-size: 16px; text-align: center; color: #9d9d9d;
}
#jg_popup_table.jg_popup_basic #jg_popup_tr {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_tl {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_b {
    height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_bl {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_br {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_l {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_r {
    width:3px; height:3px; background:#fff
}
#UserProfile {
    cursor: default;
}
#caretDownPrfl {
    display: block;
    position: absolute;
    font-size: 18px;
    color: #9ec4e5;
    margin: 1px 0px 0px 41px;
    cursor: pointer !important;
    z-index: 10;
}
#caretDownPrfl:hover {
    color: #2467a1;
}
#filterContacts {
    display: inline-block;
    position: absolute;
    font-size: 15px;
    color: #a4b5c4;
    margin: 4px 0px 0px 4px;
    padding: 2px 4px;
    border: 0;
    border-radius: 5px;
    background-color: #f9fcfe;
    cursor: pointer !important;
    z-index: 2092;
}
#filterContacts:hover {
    color: #2c60b2 !important;
}
#UserProfilePic {
    cursor: pointer !important;
}
#UserProfilePic:hover {
    box-shadow: 0 1px 5px rgba(0, 0, 0, 0.3); 
}
#userMenu {
    cursor: pointer;
    font-size: 16px;
}
#userMenu #userMenuTable tr td {
    display: block;
    margin: 4px auto;
    color: #363636;
}
#userMenu #userMenuTable tr td:hover {
    color: #000000 !important;
}
.userMenuContent { 
    padding: 0px 2px;
}
#statusLabel {
    display: inline;
    margin: 0px 8px 0px 0px;
}
#customStatusText {
    display: none;
    width: 140px;
    margin: -3px 0px 0px 0px;
    font-size: 16px;
    border-bottom: none !important;
}
#enteredCustStText {
    display: inline-block;
    width: 160px;
    margin: 0px 4px 0px 0px;
    padding: 1px 4px;
    border: 1px solid #dddddd;
}
#saveCustStatusBtn {
    display: inline-block;
    margin: 0px;
    padding: 3px 8px 4px 8px;
    border: 1px solid #42c493;
    background-color: #42c493;
    font-family: Inter, sans-serif;
    font-weight: 700;
    color: #FFFFFF;
    font-size: 14px;
    border-radius: 4px;
    cursor: pointer;
}
#saveCustStatusBtn:hover {
    border: 1px solid #39ad82;
    background-color: #39ad82;
}
#shownStatus {
    display: inline-block;
    width: 140px;
    height: auto;
    margin: 0px 0px -16px 0px;
    padding: 0px 0px 10px 0px;
    font-size: 16px;
    font-weight: 500;
    color: #306084;
    border-bottom: none !important;
    white-space: nowrap;
    overflow: hidden;
}
#statusCaretDown {
    display: inline-block;
    margin: 0px 0px 0px 10px;
    color: #647dc9;
}
#selectStatus {
    display: none;
    position: absolute;
    width: auto;
    margin: 24px 0px 0px -149px;
    padding: 0px !important;
    font-size: 16px;
    font-weight: 500;
    color: #306084;
    border-bottom: none !important;
    box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
    z-index: 2200;
}
.statusListItem {
    display: block;
    width: 170px;
    height: auto;
    padding: 7px 0px 7px 7px;
    font-size: 16px;
    background-color: #f7fffa;
}
#selectStatus li:hover {
    color: #244762;
    background-color: #ebfaf1;
}

#mainDialPad {
    padding-bottom: 8px !important;
}
#mainDtmfDialPad {
    margin: 5px 0px 0px 0px;
}
#jg_popup_inner {
   border-radius: 6px;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1)  ; 
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1)  ; 
   -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1)  ; 
}
#jg_popup_table.jg_popup_basic {
   border: 3px solid #ffffff;
   border-radius: 6px;   
}
#jg_popup_table tbody {
   border: 3px solid #ffffff;
   border-radius: 6px;
}
#AllConfMenu {
   font-size: 15px;
}
#AllConfMenu, #settingsCMenu {
   cursor: pointer;
}
#AllConfMenu #lauchConfTable {
   margin: 0px;
}
#AllConfMenu #lauchConfTable tr td {
   display: block;
   margin: 4px 0px 4px 8px !important;
   color: #363636;
}
#settingsCMenu #lauchSetConfTable tr td {
   display: block;
   margin: 0px 0px 0px 4px !important;
   color: #363636;
}
#AllConfMenu #lauchConfTable tr td:hover, #settingsCMenu #lauchSetConfTable tr td:hover {
   color: #000000 !important;
}
#textSubMenu {
   display: none;
   position: absolute;
   width: auto;
   height: auto;
   top: 8px;
   left: 200px;
   background-color: #ffffff;
   border-radius: 4px;
   padding: 5px 14px 5px 7px;
   white-space: nowrap;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   z-index: 2000;
}
#audioSubMenu {
   display: none;
   position: absolute;
   width: auto;
   height: auto;
   top: 39px;
   left: 200px;
   padding: 5px 14px 5px 7px;
   white-space: nowrap;
   background-color: #ffffff;
   border-radius: 4px;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   z-index: 2000;
}
#videoSubMenu {
   display: none;
   position: absolute;
   width: auto;
   height: auto;
   top: 70px;
   left: 200px;
   padding: 5px 14px 5px 7px;
   white-space: nowrap;
   background-color: #ffffff;
   border-radius: 4px;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   z-index: 2000;
}

.textConfPartNo, .audioConfPartNo, .videoConfPartNo {
   display: inline;
   margin: 0px 0px 0px 10px;
   color: #5b98da;
}

.textConfPartNo:hover, .audioConfPartNo:hover, .videoConfPartNo:hover {
   color: #385e87;
}
#textConfParticipants, #audioConfParticipants, #videoConfParticipants {
   display: block;
   position: absolute;
   background-color: #ffffff;
   width: auto;
   height: auto;
   padding: 4px;
   border: 0px;
   border-radius: 4px;
   white-space: nowrap;
   cursor: default;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   z-index: 2000;
}
.txtConfPartLine, .audioConfPartLine, .videoConfPartLine {
   display: block;
   width: 100%;
   height: auto;
   padding: 4px;
   color: #000000;
   font-size: 15px;
   white-space: nowrap;
}
#videoSubMenu #videoSubMenuTbl tr td, #audioSubMenu #audioSubMenuTbl tr td, #textSubMenu #textSubMenuTbl tr td  {
   display: block;
   margin: 4px 0px 4px 8px !important;
   color: #185494;
}
#videoSubMenu #videoSubMenuTbl tr td span:hover, #audioSubMenu #audioSubMenuTbl tr td span:hover, #textSubMenu #textSubMenuTbl tr td span:hover  {
     color: #042e7f;
}
#windowCtrls {
   display: block;
   position: absolute;
   float: right;
   width: auto;
   height: auto;
   top: 5px;
   right: 3px;
}
#minimizeImg, #maximizeImg, #closeImg {
   display: inline-block;
   width: 18.4px;
   height: 18.4px;
   margin: 0px 3px 0px 3px;
   cursor: pointer;
}
#minimizeImg:hover, #maximizeImg:hover, #closeImg:hover {
   box-shadow: 0 0 9px rgba(0, 0, 0, 0.1); 
   -webkit-box-shadow: 0 0 9px rgba(0, 0, 0, 0.1); 
   -moz-box-shadow: 0 0 9px rgba(0, 0, 0, 0.1); 
}
.quickNumDialRow, .quickFindBdRow, #showEmojiRow {
   color: #363636 !important;
   cursor: pointer;
}
.quickFindBdTagRow {
   color: #363636 !important;
}
.quickNumDialRow:hover, #showEmojiRow:hover {
   color: #000000 !important;
}

.callSettingsContent {
   padding: 10px 10px 16px 10px;
}
.callSettingsDvs {
   padding: 6px 0px 6px 3px;
   font-size: 14px;
   color: #b0b0b0;
}
#settingsCMenu_1 {
   z-index: 20100;
}

#leftPanelSettings tr td {
   color: #363636;
   cursor: pointer;
}
#leftPanelSettings tr td:hover {
   color: #0F4685;
}
#messageMenuTable tr td {
   color: #363636;
   cursor: pointer;
}
#messageMenuTable tr td:hover {
   color: #000000 !important;
}

#mainRightConf {
   display: block;
   position: relative;
   height: auto;
   width: auto;
   padding: 20px 20px 20px 10px;
}
#rightMainConfWindow {
    position: relative;
    height: 100%;
    width: 100%;
}
.settingsSubSection {
    display: block;
    margin: 0px 8px 80px 2px; 
}
#rightMainConfWindow .UiText {
    font-weight: 500 !important;
}
#settingsTitle {
    display: block;
    padding-right: 200px;
    margin-bottom: 8px;
}
.selectedSettingsSection {
    color: #1667C9 !important;
    font-weight: 500;
}
#AllertMessageText {
    font-size: 16px !important;
}

/* Other elements */

#roundcubeFrame {
    display: block;
    position: relative;
    height: 100%;
    width: 100%;
    z-index; 1010;
}
.fa-paper-plane-o {
    margin: 0px 2px 1px 0px;
    padding: 0px;
}
#rcLogoutFrame {
    width: 100%;
    height: 100%;
    visibility: hidden;
}
#rcForm, #rcloForm {
    visibility: hidden;
}
#enableRCcheck label {
   word-break: normal !important;
   white-space: normal !important;
}

#loaderImage {
   display: block;
   position: absolute;
   margin: auto;
   vertical-align: center;
}
#rcLogoutMessage {
   display: block;
   position: absolute;
   margin: auto;
}
.shrinkLeftContent {
   display: inline-block;
   position: absolute;
   float: left;
   height: 100%;
   width: 320px;
   left: -280px;
}
.widenRightContent {
   display: inline-block;
   position: absolute;
   margin-left: 40px !important;
   height: 100%;
   width: 97.5%;
   overflow: auto;
}
#sendFileFormChat {
   display: none;
   position: absolute;
   width: auto;
   height: auto;
   text-align: left;
   bottom: 0px;
   left: 0px;
   border-radius: 5px;
   overflow: auto;
   z-index: 1016;
}

.sendRecAudioVideo {
   display: none;
   position: absolute;
   bottom: 0px;
   width: auto;
   height: 24px;
   padding: 0px 8px;
   font-size: 15px;
   font-weight: 500;
   color: #ffffff;
   background-color: #528bd5;
   border: none;
   border-radius: 5px;
   cursor: pointer;
   z-index: 1018;
}

.sendRecAudioVideo:hover {
    background-color: #3971ba;
}

.sendRecAudioVideo:active {
    background-color: #265694;
}

.sendRecordedVid {
   display: none;
   position: absolute;
   bottom: 0px;
   width: auto;
   height: 24px;
   padding: 0px 8px;
   font-size: 15px;
   font-weight: 500;
   color: #ffffff;
   background-color: #8b6bcf;
   border: none;
   border-radius: 5px;
   cursor: pointer;
   z-index: 1018;
}

.sendRecordedVid:hover {
   background-color: #7959bc;
}

.sendRecordedVid:active {
   background-color: #583d92;
}

#recordedAudioFl, #recordedVideoFl {
   cursor: pointer;
   z-index: 1017;
}

.customBrowseButton {
    display: inline-block;
    padding: 2px 8px;
    background-color: #6ac9aa;
    border: 1px solid #6ac9aa;
    font-family: Inter, sans-serif;
    font-weight: 600;
    color: #ffffff;
    font-size: 15px;
    border-radius: 4px;
    margin: 15px auto;
    cursor: pointer;
}

.customBrowseButton:hover {
    background-color: #63bc9f;
    border: 1px solid #63bc9f;
    box-shadow: none  !important;
}

.customBrowseButton:active {
    background-color: #58a88e;
    border: 1px solid #58a88e;
    box-shadow: none  !important;
}

.custBrowseBttnSfl {
   display: inline-block;
   position: relative;
   width: auto;
   height: 24px;
   padding: 0px 8px;
   font-size: 15px;
   font-weight: 500;
   color: #ffffff;
   cursor: pointer;
   background-color: #6ac9aa;
   border: 1px solid #6ac9aa;
   border-radius: 4px;
}
.custBrowseBttnSfl:hover {
   background-color: #63bc9f;
   border: 1px solid #63bc9f;
   box-shadow: none  !important;
}
.custBrowseBttnSfl:active {
   background-color: #58a88e;
   border: 1px solid #58a88e;
   box-shadow: none  !important;
}
#upFile {
   display: none;
   position: relative;
   min-width: 68px;
   height: 24px;
   vertical-align: bottom;
   color: #393939;
   font-size: 16px;
   padding: 0px 10px;
   margin-left: 3px;
   background-color: rgba(219, 234, 255, 0.75);
   border-radius: 4px;
   z-index: 2001;
}
.upRecFileNmSpace {
   display: inline-block;
   position: absolute;
   bottom: 0px;
   min-width: 68px;
   height: 24px;
   color: #393939;
   font-size: 16px;
   padding: 0px 10px;
   margin-left: 3px;
   background-color: rgba(219, 234, 255, 0.75);
   border-radius: 4px;
   z-index: 2001;
}
.sentFileChatRect {
   display: block;
   position: relative;
   float: right;
   padding: 8px 14px;
   height: auto;
   width: auto;
   font-size: 16px;
   color: #393939;
   background-color: #E9F4FF;
   border-radius: 4px;
   text-align: center;
   word-wrap: break-word;
}
.sentFileChatRect a {
   text-decoration: none;
   color: #1157a0 !important;
}
.recFileChatRect {
   display: block;
   position: relative;
   float: left;
   padding: 8px 14px;
   height: auto;
   width: auto;
   font-size: 16px;
   color: #393939;
   background-color: #E3FAEF;
   border-radius: 4px;
   text-align: center;
   word-wrap: break-word;
}
.recFileChatRect a {
   text-decoration: none;
   color: #1157a0 !important;
}

.audiovidFlREC {
   display: none;
   position: absolute;
   bottom: 0px;
   padding: 0px 6px;
   border: 1px solid #dc4343;
   border-radius: 5px;
   color: #dc4343;
   font-size: 15px;
   font-weight: 500;
   z-index: 2000;
}
#sendFileLoader, .sendFileLoaderTC {
   display: block;
   position: fixed;
   top: 50%;
   left: 50%;
   width: 60px;
   height: 60px;
   border: 8px solid #f1f1f1;
   border-radius: 50%;
   border-top: 8px solid #339be1;
   -webkit-animation: flspin 2s linear infinite;
   animation: flspin 2s linear infinite;
}

#sendFileLoadermgr {
   display: block;
   position: fixed;
   top: 60%;
   left: 50%;
   width: 60px;
   height: 60px;
   border: 8px solid #f1f1f1;
   border-radius: 50%;
   border-top: 8px solid #339be1;
   -webkit-animation: flspin 2s linear infinite;
   animation: flspin 2s linear infinite;
}

@-webkit-keyframes flspin {
   0% { -webkit-transform: rotate(0deg); }
   100% { -webkit-transform: rotate(360deg); }
}

@keyframes flspin {
   0% { transform: rotate(0deg); }
   100% { transform: rotate(360deg); }
}

#openTConfLoader {
   display: block;
   position: absolute;
   top: 50%;
   left: 50%;
   width: 66px;
   height: 66px;
   background-image: url('../images/loader.gif');
   background-repeat: no-repeat;
   z-index: 2050;
}

#getBalanceLoader {
   display: block;
   position: absolute;
   width: 20px;
   height: 20px;
   top: -4px;
   right: 7px;
   border: 6px solid #f1f1f1;
   border-radius: 50%;
   border-top: 6px solid #339be1;
   -webkit-animation: flspin 2s linear infinite;
   animation: flspin 2s linear infinite;
   z-index: 5000;
}

.croppie-container .cr-slider-wrap {
   margin: 7px auto !important;
}


/* Text conference */

.publicTextCnfMessage {
    display: none;
    position: absolute;
    background-color: #ffffff;
    border: 0px;
    border-radius: 6px;
    box-shadow: rgba(0, 0, 0, 0.3) 0px 0px 23px;
    -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
    z-index: 22;
}

.windowCtrlsTC {
   position: absolute;
   float: right;
   width: auto;
   height: auto;
   top: 10px;
   right: 8px;
   user-select: none;
   z-index: 21;
}

.windowCtrlsTCPM {
   position: absolute;
   float: right;
   width: auto;
   height: auto;
   top: 9px;
   right: 7px;
   user-select: none;
   z-index: 21;
}

.dragPubMessage {
   display: block;
   position: absolute;
   width: 100%;
   height: 10px;
   top: -2px;
   text-align: center;
   z-index: 21;
}

.minimizeImgTextCnf, .maximizeImgTextCnf, .restoreImgTextCnf, .closeImgTextCnf {
   display: inline-block;
   width: 18.4px;
   height: 18.4px;
   margin: 0px 3px 0px 3px;
   cursor: pointer;
   float: right;
}

.minimizeImgTextCnf:hover, .maximizeImgTextCnf:hover, .restoreImgTextCnf:hover, .closeImgTextCnf:hover {
   box-shadow: 0 0 9px rgba(0, 0, 0, 0.1); 
   -webkit-box-shadow: 0 0 9px rgba(0, 0, 0, 0.1); 
   -moz-box-shadow: 0 0 9px rgba(0, 0, 0, 0.1); 
}

.textConfMinLabel {
   display: none;
   width: 280px;
   height: auto;
   text-align: center;
   margin: -1px -16px 0px 0px;
   color: #3367AB;
   font-size: 16px;
   font-weight: 600;
}

.txtCnfTblAll {
   display: block;
   width: 101%;
   height: 90%;
   overflow: auto;
}

.txtCnfTableUaT {
   display: block;
   width: auto;
   height: auto;
   margin: 0px 23px;
}

.tConfUsersList {
   display: block;
   position: relative;
   width: 182px;
   height: 510px;
   padding: 1px;
   border-radius: 3px;
   background-color: #f2f8ff;
   overflow-y: auto;
}

.receiveTextMessage {
   display: block;
   position: relative;
   width: 567px;
   height: 510px;
   font-size: 16px;
   color: #333333;
   text-align: left;
   background-color: #f4fdfc;
   border: 0px;
   border-radius: 3px;
   margin-left: 5px;
   user-select: text !important;
   overflow-y: auto;
   overflow-x: auto;
}

.sendMsgTConf {
   display: block;
   position: relative;
   width: auto;
   height: 114px;
   padding: 1px;
   font-size: 16px;
   color: #333333;
   text-align: left;
   background-color: #f3fcff;
   border: 0px;
   border-radius: 3px;
   margin: 5px 23px 0px 23px;
}

.textCnfBoxBtns {
   display: block;
   width: 36px;
   height: 100%;
   margin: 0px;
   padding: 1px;
}

.tcPartListItem {
   display: block;
   margin: 3px 2px;
   padding: 3px 2px;
   color: #224573;
   background-color: #ffffff;
   word-break: normal;
   border: 0px;
   border-radius: 6px;
   cursor: pointer;
}

.tcPartListItem:hover { 
   background-color: #d7e4f4;
}

.tcPartListItemIt {
   display: block;
   margin: 3px 2px;
   padding: 3px 2px;
   color: #282828;
   background-color: #ffffff;
   word-break: normal;
   border: 0px;
   border-radius: 6px;
   cursor: default;
}

.privateMessageImgTC {
   display: none;
   margin: 0px 9px 0px 3px;
   float: left;
}

.sendMessageTbl {
    display: block;
    position: relative;
    width: 100%;
    height: 100%;
}

.chatMessageTC {
    box-sizing: border-box;
    width: 100%;
    height: 112px;
    padding: 3px 6px;
    border: none;
    outline: none;
    resize: none;
    font-family: Inter, sans-serif;
    font-size: 15px;
    color: #282828;
    background-color: transparent;
    overflow-y: auto;
}

.textMessageSent, .textMessageSentPM {
    display: block;
    width: auto;
    height: auto;
    margin: 7px !important;
    padding: 6px 10px;
    background-color: #e9f4ff;
    border: 1px solid #e9f4ff;
    border-radius: 5px;
    font-family: Inter, sans-serif;
    font-size: 15px;
    color: #282828;
    user-select: text;
    cursor: text;
    word-break: keep-all;
}

.textMessageReceived, .textMessageReceivedPM {
    display: block;
    width: auto;
    height: auto;
    margin: 7px !important;
    padding: 6px 10px;
    background-color: #e4f7ee;
    border: 1px solid #e4f7ee;
    border-radius: 5px;
    font-family: Inter, sans-serif;
    font-size: 15px;
    color: #282828;
    user-select: text;
    cursor: text;
    word-break: keep-all;
}

.textMessageSent a, .textMessageReceived a, .textMessageSentTCPM a, .textMessageReceivedTCPM a {
   text-decoration: none;
   color: #1157a0 !important;
}

.sentMessageNm {
    border: 0px;
    border-radius: 6px;
    padding: 2px 5px 2px 6px;
    margin: 0px 4px 0px 0px;
    color: #414141;
    background-color: #ffffff;
    font-size: 15px;
}

.recMessageNm {
    border: 0px;
    border-radius: 6px;
    padding: 2px 5px 2px 6px;
    margin: 0px 4px 0px 0px;
    color: #224573;
    background-color: #ffffff;
    font-size: 15px;
    cursor: pointer;
}

.recMessageNm:hover {
    background-color: #cdeadc;
}

.smTConfcont {
    display: inline;
    margin-left: 4px;
}

.messageDate {
   display: block;
   margin: 5px 0px 2px 0px;
   font-size: 12px;
   color: #666666;
}

.messageFlDate {
    display: block;
    width: 100%;
    margin-top: 4px;
    font-size: 12px;
    color: #666666;
}

.sendFileFormTextCnf, .fileSendTCPM {
   display: none;
   position: absolute;
   width: auto;
   height: auto;
   text-align: left;
   bottom: 0px;
   left: 4px;
   border-radius: 5px;
   overflow: auto;
   z-index: 1016;
}

input[type="file"] {
   display: none;
}

.customBrowseBtnTC {
   display: inline-block;
   position: relative;
   width: auto;
   height: 24px;
   padding: 0px 8px;
   font-size: 16px;
   font-weight: 500;
   color: #ffffff;
   cursor: pointer;
   background-color: #65c98d;
   border-radius: 4px;
}

.customBrowseBtnTC:hover {
   background-color: #60B582;
}

.customBrowseBtnTC:active {
   background-color: #569c72;
}

.upFileTextCnf {
   display: none;
   position: relative;
   min-width: 80px;
   height: 24px;
   vertical-align: bottom;
   color: #393939;
   font-size: 16px;
   padding: 0px 8px;
   margin-left: 3px;
   background-color: rgba(219, 234, 255, 0.75);
   border-radius: 4px;
}

.downTextConfHst, .downloadTConfHstTCPM {
   display: none;
   position: absolute;
   top: 3px;
   right: 12px;
   font-size: 18px;
   color: #9d9d9d;
   cursor: pointer;
}

.downTextConfHst:hover, .downloadTConfHstTCPM:hover {
   color: #4b4b4b;
}

.downTextConfHst:active, .downloadTConfHstTCPM:active {
   color: #000000;
}

.recTCPubMessageNotify {
   display: inline-block;
   position: absolute;
   bottom: 2px;
   left: 300px;
   font-size: 28px;
   cursor: pointer;
   z-index: 1000;
}

.recTCPrivMessageNotify {
   display: inline-block;
   position: absolute;
   bottom: 2px;
   left: 581px;
   font-size: 28px;
   cursor: pointer;
   z-index: 1000;
}

/* Text conference private messages */
.textMessagesTCPM {
   display: none;
   position: absolute;
   width: 610px;
   height: 490px;
   padding: 4px 2px;
   background-color: #ffffff;
   border: 0px;
   border-radius: 6px;
   box-shadow: rgba(0, 0, 0, 0.3) 0px 0px 23px;
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
   -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
   z-index: 22;
}

.minimizeImgTCPM, .maximizeImgTCPM, .restoreImgTCPM, .closeImgTCPM {
   display: inline-block;
   width: 18.4px;
   height: 18.4px;
   margin: 0px 3px 0px 3px;
   cursor: pointer;
   float: right;
}

.receiveTextMessageTCPM {
   display: block;
   position: relative;
   margin: 8px auto;
   width: 93%;
   height: 58%;
   padding: 0px;
   font-size: 16px;
   color: #333333;
   background-color: #f4fdfc;
   text-align: left;
   border: 0;
   border-radius: 3px;
   overflow-y: auto;
   overflow-x: auto;
}

.sendTMessageTCPM {
   display: block;
   position: relative;
   margin: 3px auto 0px auto;
   width: 93%;
   height: 112px;
   padding: 1px;
   font-size: 16px;
   color: #333333;
   text-align: left;
   background-color: #f3fcff;
   border: 0;
   border-radius: 3px;
}

.chatMessageTCPM {
   box-sizing: border-box;
   width: 100%;
   height: 112px;
   padding: 3px 6px;
   border: none;
   outline: none;
   resize: none;
   font-family: Inter, sans-serif;
   font-size: 15px;
   color: #282828;
   background-color: transparent;
   overflow-y: auto;
}

.textMessageSentTCPM {
   display: block;
   width: 93.5%;
   height: auto;
   padding: 6px 10px;
   margin: 8px auto;
   background-color: #e9f4ff;
   border: 1px solid #e9f4ff;
   border-radius: 5px;
   font-family: Inter, sans-serif;
   font-size: 15px;
   color: #282828;
   user-select: text;
   cursor: text;
   word-break: keep-all;
}

.textMessageReceivedTCPM {
   display: block;
   width: 93.5%;
   height: auto;
   padding: 6px 10px;
   margin: 8px auto;
   background-color: #e4f7ee;
   border: 1px solid #e4f7ee;
   border-radius: 5px;
   font-family: Inter, sans-serif;
   font-size: 15px;
   color: #282828;
   user-select: text;
   cursor: text;
   word-break: keep-all;
}

.recMessageBtnTCPM {
   border: 0px;
   border-radius: 6px;
   padding: 2px 6px;
   margin: 0px 4px 0px 0px;
   color: #282828;
   background-color: #ffffff;
   font-size: 15px;
}

.sentMessageBtnTCPM {
   border: 0px;
   border-radius: 6px;
   padding: 2px 5px 2px 6px;
   margin: 0px 4px 0px 0px;
   color: #414141;
   background-color: #ffffff;
   font-size: 15px;
}

.srMsgTConfcont {
   display: inline;
   margin-left: 4px;
}

.EmojiMenuTC {
   position: absolute;
   display: none;
   width: 320px;
   height: auto;
   bottom: 144px;
   right: 25px;
   background-color: #ffffff;
   border-radius: 4px;
   box-shadow: 0 0 7px rgba(0, 0, 0, 0.1);
   z-index: 25;
}

.emojiMenuTCPM {
   position: absolute;
   display: none;
   width: 320px;
   height: auto;
   bottom: 145px;
   right: 25px;
   background-color: #ffffff;
   border-radius: 4px;
   box-shadow: 0 0 7px rgba(0, 0, 0, 0.1);
   z-index: 25;
}

.fileSendTCPM {
   display: none;
   position: absolute;
   width: auto;
   height: auto;
   text-align: left;
   bottom: 0px;
   left: 0px;
   border-radius: 5px;
   overflow: auto;
   z-index: 23;
}

.customBrowseButtonTCPM {
   display: inline-block;
   position: relative;
   width: auto;
   height: 24px;
   padding: 0px 8px;
   font-size: 16px;
   font-weight: 500;
   color: #ffffff;
   cursor: pointer;
   background-color: #65c98d;
   border-radius: 4px;
}

.uploadedFlTCPM {
   display: none;
   position: relative;
   min-width: 80px;
   height: 20px;
   vertical-align: bottom;
   color: #393939;
   font-size: 16px;
   padding: 0px 8px 5px 8px;
   margin-left: 3px;
   background-color: rgba(219, 234, 255, 0.75);
   border-radius: 4px;
}

.downloadVConfHstTCPM {
   display: none;
   position: absolute;
   top: 3px;
   right: 12px;
   font-size: 18px;
   color: #9d9d9d;
   cursor: pointer;
}

.privTConfMsgUpTitle {
   display: block;
   width: 100%;
   margin: 11px 0px 0px 0px;
   font-size: 16px;
   font-weight: 600;
   text-align: center;
   color: #224573;
   user-select: none;
}

.privTConfMsgTitle {
   display: block;
   width: 100%;
   margin: 0;
   font-size: 16px;
   font-weight: 600;
   text-align: center;
   color: #3e85a1;
   user-select: none;
}

.showConnectedNmb {
   display: inline-block;
   width: 16px;
   height: 16px;
   font-size: 13px;
   cursor: pointer;
}

#connectedNmbrsList {
   display: none;
   position: absolute;
   width: 172px;
   height: auto;
   padding: 8px 14px;
   color: #000000;
   background-color: #ffffff;
   border: 0;
   border-radius: 6px;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   white-space: normal;
   cursor: default;
   user-select: text !important;
   z-index: 2000;
}

.addGroupsToContact, .loadContactGroups, .exportContactGrps, .removeContactGrps {
   display: block;
   width: 100% !important;
   height: auto;
   line-height: 22px;
   border-bottom: 2px solid #cedaeb;
   margin-bottom: 15px !important;
   font-size: 16px !important;
   color: #333333 !important;
   padding-top: 10px !important;
   padding-bottom: 10px !important;
}

.contactGroupsSelect {
   display: block;
   margin: 10px 0px 6px 0px;
   width: 100%;
   color: #193b66;
   font-size: 15px;
}

#slctdGroupsToLoad {
   display: none;
   position: relative;
   width: 100%;
   height: auto;
   z-index: 1000;
}

#selectGroupToLoad {
   display: block;
   position: relative;
   background-color: #fafafa;
   width: 100%;
   height: auto;
   color: #193b66;
   font-size: 14px;
   padding: 6px 0px 4px 0px;
}

.slctdGroup, .slctdGrouplg, .slctdGroupebgr, .slctdGroupebgrrm, .slctdGroupmsgtg {
   display: inline-block;
   position: relative;
   width: auto;
   height: auto;
   padding: 6px 10px;
   color: #333333;
   background-color: #ffffff;
   border: 0;
   border-radius: 6px;
   -webkit-box-shadow: 0 0 13px rgba(0, 0, 0, 0.17);
   white-space: normal;
   cursor: default;
   user-select: text !important;
   font-weight: 500;
   font-size: 15px;
   margin: 3px;
}

#slctdGroupmgrbl {
   display: inline-block;
   position: relative;
   width: auto;
   height: auto;
   padding: 6px 10px;
   color: #333333;
   background-color: #ffffff;
   border: 2px solid #0f86ef;
   border-radius: 6px;
   -webkit-box-shadow: 0 0 13px rgba(0, 0, 0, 0.17);
   white-space: normal;
   cursor: default;
   user-select: text !important;
   font-weight: 500;
   font-size: 15px;
   margin: 3px;
}

#slctdGroupmgrgr {
   display: inline-block;
   position: relative;
   width: auto;
   height: auto;
   padding: 6px 10px;
   color: #333333;
   background-color: #ffffff;
   border: 2px solid #04a671;
   border-radius: 6px;
   -webkit-box-shadow: 0 0 13px rgba(0, 0, 0, 0.17);
   white-space: normal;
   cursor: default;
   user-select: text !important;
   font-weight: 500;
   font-size: 15px;
   margin: 3px;
}

.slctdGroupText, .slctdGroupTextEd, .slctdGroupTextlg, .slctdGroupTextgr, .slctdGroupTextgrrm, .slctdGroupTextmsgr {
   display: inline;
   position: relative;
}

.removeGroup, .removeGrouplg, .removeGroupex {
   display: inline;
   position: relative;
   color:#868686;
   font-size: 14px;
   font-weight: 500;
   margin: 0px 0px 0px 7px;
   cursor: pointer;
}

.removeGroup:hover, .removeGrouplg:hover, .removeGroupex:hover {
   color: #b70000;
}

#cnfwGroupsList {
   display: block;
   width: 100%;
   height: 160px;
   overflow: auto;
   color: #3b3b3b;
   border: 1px solid #c7d4e7;
   border-radius: 6px;
   margin: 13px 0px 50px 0px;
}

#roundpinUsersTbl, #bannedUsersTbl {
   table-layout: auto;
   width: 100%;
   margin-top: 19px;
   border: 0;
}

#roundpinUsersTbl tr, #bannedUsersTbl tr {
   display: table-row;
   border: 0;
}

#roundpinUsersTbl .thRuTableRow td {
   padding: 3px 0px 4px 3px !important;
   background-color: #f5fcfe;
   color: #595959;
   font-size: 14px;
   font-weight: 500;
   border: 0;
   text-shadow: 1px 1px 5px rgba(0, 0, 0, 0.07);
}

#roundpinUsersTbl .btnRuTableRow td {
   padding: 4px;
   color: #3b3b3b;
   font-size: 14px;
   border: 0;
}

.grpsOfUserList {
   display: inline-block;
   width: auto;
   height: auto;
   overflow: auto;
   padding: 0px 6px 0px 0px;
   cursor: pointer;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
}

.addGrpsToUserList  {
   display: block;
   width: auto;
   height: auto;
   overflow: auto;
   padding: 3px 3px 1px 1px;
   cursor: pointer;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
}

.groupsOfUserRow {
   display: none;
   white-space: nowrap;
}

.groupsOfUser {
   display: inline-block;
   color: #3b3b3b;
   font-size: 14px;
   padding: 4px;
   white-space: nowrap;
}

.rmvGrpFromUser {
   display: inline-block;
   color:#868686;
   font-size: 13px;
   font-weight: 500;
   margin-left: 5px;
   cursor: pointer;
}

.addGrpToUser {
   display: inline-block;
   color:#868686;
   font-size: 13px;
   font-weight: 500;
   margin-left: 5px;
   cursor: pointer;
}

.rmvGrpFromUser:hover, .addGrpToUser:hover {
   color: #ba0101;
}

.lightBlueBckgrnd {
   background-color: #eff5fb;
}

.lightGreenBckgrnd {
   background-color: #f2fff8;
}

.grofusrAddLabel {
   text-align: center;
   color: #03366c;
   cursor: pointer;
}

.selectUserRole {
   appearance: listbox;
   max-width: 71px;
   font-size: 14px;
   color: #333333;
   padding: 0;
   line-height: 22px;
   vertical-align: middle;
   border: none;
   background-color: transparent;
   cursor: pointer;
   white-space: nowrap;
}

.groupsListTip {
   position: relative;
   display: inline-block;
   z-index: 2200;
}

#groupsListInfo {
   margin: 0px 0px 0px 7px;
   color: #5c8cbf;
   font-weight: 600;
   font-size: 14px;
   vertical-align: text-top;
}

.groupsListInfoText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 8px;
   left: 20px;
   width: 180px;
   height: auto;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.groupsListTip:hover .groupsListInfoText {
   visibility: visible;
}


#bannedUsersTbl .thBanTableRow td {
   padding: 3px 0px 4px 3px !important;
   background-color: #f5fcfe;
   color: #595959;
   font-size: 13px;
   font-weight: 500;
   border: 0;
   text-shadow: 1px 1px 5px rgba(0, 0, 0, 0.07);
}

#bannedUsersTbl .btnBanTableRow td {
   padding: 4px;
   color: #3b3b3b;
   font-size: 13px;
   border: 0;
}

.unbanUsr {
   display: block;
   width: auto;
   height: auto;
   padding: 2px;
   color: #4B77B1;
   font-size: 16px;
   text-align: center;
   cursor: pointer;
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
}

.unbanUsr:hover {
   color: #9A0404;
}

.pickBanTime {
   display: block;
   max-width: 80px !important;
   height: auto;
   font-size: 13px !important;
   color: #0067b2 !important;
   font-weight: 500;
}

.btnBanTableRow .date-picker-x {
   top: -170px !important;
   left: -170px !important;
}

#exportAllContacts, #exportCntctsByGroup, #exportCntctsByDate, #removeAllContacts, #removeCntctsByGroup, #removeCntctsByDate {
   display: none;
   width: 80%;
   height: auto;
   margin: 20px 0px;
   padding-left: 40px;
   color: #3b3b3b;
   font-size: 14.5px;
}

#csvDelimiterList, #csvDelimiterListgr, #csvDelimiterListdt {
   display: block;
   margin: 12px 0px 20px 0px;
   width: 100%;
   color: #193b66;
   font-size: 15px;
}

#pickDateForExpst, #pickDateForExpfn, #pickDateForDelst, #pickDateForDelfn {
   display: inline-block;
   width: 40%;
   color: #3b3b3b;
   font-size: 15px;
   margin: 12px 30px 30px 0px;
}

#importContacts {
   display: block;
   width: 80%;
   height: auto;
   margin: 20px 0px;
   padding-left: 40px;
   color: #3b3b3b;
   font-size: 14.5px;
}

.delimitAndRowImport {
   margin: 10px 0px 24px 0px;
   width: 150px;
   padding: 2px 0px;
   color: #3b3b3b;
}

.nbCntctsImportMatch {
   width: 160px;
   padding: 0px 6px !important;
   color: #3b3b3b;
   line-height: 22px;
   border-bottom: none !important;
}

.nameCtImportMatch {
   padding: 3px 0px 0px 6px !important;
}

#CntctsImportMatch {
   margin: 20px 0px;
   width: 100%;
   height: auto;
}

#sendFileCImp {
   width: auto;
   height: auto;
   text-align: left;
}

#upFileCImp {
   display: inline-block;
   width: 260px;
   padding: 1px 0px 0px 16px;
   word-break: break-all;
}

#sendFileCImpTbl {
   display: block;
   width: 100%;
   margin: 26px 0px 18px 0px;
}

.rcBasicAuthTip {
   position: relative;
   display: inline-block;
   z-index: 2200;
}

#rcBasicAuthInfo {
   margin: 0px 0px 0px 7px;
   color: #5c8cbf;
   font-weight: 600;
   font-size: 14px;
   vertical-align: text-top;
}

.rcBasicAuthText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 20px;
   left: -160px;
   width: 280px;
   height: auto;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.rcBasicAuthTip:hover .rcBasicAuthText {
   visibility: visible;
}

.rcpwBasicAuthTip {
   position: relative;
   display: inline-block;
   z-index: 2100;
}

#rcpwBasicAuthInfo {
   margin: 0px 0px 0px 7px;
   color: #5c8cbf;
   font-weight: 600;
   font-size: 14px;
   vertical-align: text-top;
}

.rcpwBasicAuthText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 20px;
   left: -160px;
   width: 280px;
   height: auto;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.rcpwBasicAuthTip:hover .rcpwBasicAuthText {
   visibility: visible;
}

.userRoleTip {
   position: relative;
   display: inline-block;
   z-index: 3310;
}

#userRoleInfo {
   margin: 0px 0px 0px 7px;
   color: #5c8cbf;
   font-weight: 600;
   font-size: 14px;
   vertical-align: top;
}

.userRoleText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 17px;
   left: -120px;
   width: 320px;
   max-height: 386px;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.userRoleTip:hover .userRoleText {
   visibility: visible;
}

.voicePhNoTip, .expCharTipAll, .expCharTipGr, .expCharTipDt, .firstRowNbTip, .fieldNbTip {
   position: relative;
   display: inline-block;
   z-index: 3300;
}

.sendMsgToGrpTip {
   position: fixed;
   display: inline-block;
   z-index: 3320;
}

.sendSMSToGrpTip {
   position: fixed;
   display: inline-block;
   z-index: 3310;
}

.faxTitleTip {
   position: relative;
   display: inline-block;
   z-index: 3341;
}

.telnyxKeyTip {
   position: relative;
   display: inline-block;
   z-index: 3343;
}

.telnyxWhUrlTip {
   position: relative;
   display: inline-block;
   z-index: 3342;
}

.telnyxAppIdTip {
   position: relative;
   display: inline-block;
   z-index: 3341;
}

.phaxKeyTip {
   position: relative;
   display: inline-block;
   z-index: 3340;
}

.phaxSecretTip {
   position: relative;
   display: inline-block;
   z-index: 3335;
}

.phaxWhtokenTip {
   position: relative;
   display: inline-block;
   z-index: 3334;
}

.phaxRecurlTip {
   position: relative;
   display: inline-block;
   z-index: 3332;
}

.importCntsTip, .voicePhNoTip, .smsPhNoTip, .faxPhNoTip {
   position: relative;
   display: inline-block;
   z-index: 3330;
}

.vdefPhNoTip, .smsdefPhNoTip, .faxdefPhNoTip {
   position: absolute;
   display: inline-block;
   z-index: 3310;
}

#voicePhNoInfo, #vdefPhNoInfo, #smsPhNoInfo, #smsdefPhNoInfo, #faxPhNoInfo, #faxdefPhNoInfo, #expCharInfoAll, #expCharInfoGr,
#expCharInfoDt, #firstRowInfo, #fieldNbInfo, #sendMsgToGrpInfo, #sendSMSToGrpInfo, #importCntsInfo, #phaxKeyInfo, #phaxSecretInfo,
#phaxWhtokenInfo, #phaxRecurlInfo, #faxTitleInfo, #telnyxKeyInfo, #telnyxAppIdInfo, #telnyxWhUrlInfo {
   margin: 0px 0px 0px 7px;
   color: #5c8cbf;
   font-weight: 600;
   font-size: 14px;
   vertical-align: top;
}

.voicePhNoText, .smsPhNoText, .faxPhNoText, .phaxKeyText, .phaxSecretText,
.phaxWhtokenText, .telnyxKeyText, .telnyxAppIdText, .telnyxWhUrlText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -110px;
   width: 340px;
   height: auto;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.vdefPhNoText, .smsdefPhNoText, .faxdefPhNoText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -230px;
   width: 340px;
   height: auto;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.phaxRecurlText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -220px;
   width: 340px;
   height: auto;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.faxTitleText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -200px;
   width: 230px;
   height: auto;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.voicePhNoTip:hover .voicePhNoText, .vdefPhNoTip:hover .vdefPhNoText, .smsPhNoTip:hover .smsPhNoText, .smsdefPhNoTip:hover .smsdefPhNoText,
.faxPhNoTip:hover .faxPhNoText, .faxdefPhNoTip:hover .faxdefPhNoText, .phaxKeyTip:hover .phaxKeyText, .phaxSecretTip:hover .phaxSecretText,
.phaxWhtokenTip:hover .phaxWhtokenText, .phaxRecurlTip:hover .phaxRecurlText, .faxTitleTip:hover .faxTitleText, .telnyxKeyTip:hover .telnyxKeyText,
.telnyxAppIdTip:hover .telnyxAppIdText, .telnyxWhUrlTip:hover .telnyxWhUrlText {
   visibility: visible;
}

.expCharTextAll {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -90px;
   width: 250px;
   max-height: 310px;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.expCharTipAll:hover .expCharTextAll {
   visibility: visible;
}

.expCharTextGr, .expCharTextDt {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -90px;
   width: 250px;
   max-height: 240px;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.expCharTipGr:hover .expCharTextGr {
   visibility: visible;
}

.expCharTipDt:hover .expCharTextDt {
   visibility: visible;
}

#expContactsByDateBtn {
   margin-top: 6px;
}

.firstRowText, .fieldNbText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -76px;
   width: 300px;
   height: auto;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.sendMsgToGrpText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -260px;
   width: 300px;
   max-height: 320px;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.sendSMSToGrpText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -276px;
   width: 300px;
   max-height: 320px;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.importCntsText {
   display: block;
   position: absolute;
   visibility: hidden;
   top: 16px;
   left: -76px;
   width: 260px;
   height: auto;
   padding: 6px 12px;
   color: #545454;
   font-size: 15px;
   font-weight: 500;
   border-radius: 6px;
   overflow-y: auto;
   background-color: #fafafa;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1);
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.23);
}

.firstRowNbTip:hover .firstRowText {
   visibility: visible;
}

.fieldNbTip:hover .fieldNbText {
   visibility: visible;
}

.sendMsgToGrpTip:hover .sendMsgToGrpText {
   visibility: visible;
}

.sendSMSToGrpTip:hover .sendSMSToGrpText {
   visibility: visible;
}

.importCntsTip:hover .importCntsText {
   visibility: visible;
}

#removeAllCntctsBtn {
   margin-top: 7px;
}

#removeCntctsByGrpBtn {
   margin-top: 14px;
}

.UiTextMod {
   font-family: Inter, sans-serif;
   color: #193b66;
   font-size: 15px;
   margin-top: 8px;
   font-weight: 600 !important;
}

#windowCtrlsMsggrp {
   position: absolute;
   float: right;
   width: auto;
   height: auto;
   top: 10px;
   right: 8px;
   user-select: none;
   z-index: 21;
}

#showTextMessagemgr {
   display: block;
   position: relative;
   width: 100%;
   height: 160px;
   margin: 0px;
   font-size: 16px;
   color: #333333;
   text-align: left;
   background-color: #f5fffe;
   border: 1px solid #d8edff;
   border-radius: 3px;
   user-select: text !important;
   overflow: auto;
}

#msgToGroups {
   display: none;
   position: absolute;
   background-color: #ffffff;
   border: 0px;
   border-radius: 6px;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
   z-index: 3300;
}

#txtToGroupsSend {
   display: block;
   width: auto;
   height: 100%;
   padding: 0px 30px 0px 30px;
}

#addContactGrpsmgr {
   display: block;
   margin: 10px 0px 0px 0px;
   width: 100%;
   color: #193b66;
   font-size: 15px;
}

#msgtoGrpTxtSend {
   display: block;
   position: relative;
   width: auto;
   height: 100px;
   padding: 1px;
   font-size: 16px;
   color: #333333;
   text-align: left;
   background-color: #f3f8ff;
   border: 1px solid #e2edfb;
   border-radius: 3px;
   margin: 5px 0px 0px 0px;
}

#addContactGroupsMgr {
   display: block;
   width: 100%;
   height: 40px;
   white-space: nowrap;
   overflow-x: auto;
   overflow-y: hidden;
   line-height: 22px;
   border-bottom: 2px solid #cedaeb;
   margin-bottom: 12px !important;
   font-size: 16px !important;
   color: #333333 !important;
   padding-top: 8px !important;
   padding-bottom: 8px !important;
}

.sendIMsgToGroups {
   display: block;
   min-height: 57px;
   margin: 0px;
   color: #01458f !important;
   font-size: 15px;
}

.sendIMsgToGroups label {
   word-break: normal !important;
   white-space: normal !important;
   margin-bottom: 12px;
   font-size: 15px;
   color: #01458f !important;
}

#textToGrpsBoxBtns {
   display: block;
   width: 36px;
   height: 100%;
   padding: 13px 6px;
}

.EmojiMenumgr {
   position: absolute;
   display: none;
   width: 320px;
   height: auto;
   bottom: 138px;
   right: 34px;
   background-color: #ffffff;
   border-radius: 4px;
   box-shadow: 0 0 7px rgba(0, 0, 0, 0.1);
   z-index: 3310;
}

#sendMsgToGrpsLabel {
   display: none;
   width: 300px;
   height: auto;
   text-align: center;
   margin: -2px -12px 0px 0px;
   color: #3367AB;
   font-size: 16px;
   font-weight: 600;
}

#sendTextMessagemgr {
   box-sizing: border-box;
   width: 100%;
   height: 100px;
   padding: 3px 6px;
   border: none;
   outline: none;
   resize: none;
   font-family: Inter, sans-serif;
   font-size: 15px;
   color: #282828;
   background-color: transparent;
   overflow-y: auto;
}

.mgrImSentStatus, .mgrEmSentStatus, .mgrSmSentStatus {
   display: inline-block;
   margin: 0px 4px;
   color: #38c4a6;
   font-size:13px;
}

/* Fax */
#sendFaxFrame {
   display: none;
   position: absolute;
   top: 0;
   right: 0;
   left: 320px;
   background-color: #fafafa;
   border-top: 6px solid #f0f5fc;
   border-bottom: 6px solid #f0f5fc;
   border-right: 6px solid #f0f5fc;
   border-left: 5px solid #f0f5fc;
}

#srfax_vbar {
   position: absolute;
   top: 0;
   width: 280px;
   padding: 18px;
   font-family: Inter, sans-serif;
   color: #363636;
   border-right: 5px solid #f0f5fc;
   background-color: #fafafa;
   overflow: auto;
}

#sendFaxContent {
   position: absolute;
   left: 336px;
   height: 100%;
   color: #000000;
   background-color: #fafafa;
   overflow: auto;
}

#srfax_vbar a {
   text-decoration: none;
}

#currentbaldiv {
   display: block;
   position: relative;
   height: 30px;
   margin: 0px 0px 8px 0px;
   background-color: #5A8FD4;
   border-radius: 4.5px;
}

#faxnumbersdiv {
  display: block;
  position: relative;
  font-size: 17px;
  font-weight: bold;
  height: 30px;
  margin: 0px 0px 20px 0px;
  color: #000000;
  background-color: #5A8FD4;
  border-radius: 4.5px;
}

#selectPrvBalance {
  display: inline-block;
  position: absolute;
  height: 100%;
  width: 34%;
  margin: 0.8px 0px 0px 5px;
  padding: 1px 0px 0px 0px;
  font-size: 15px;
  text-align: center;
  color: #353535;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  background: #fcfcfc;
  border-radius: 20px !important;
}

#currentfaxnmbrs {
  display: inline-block;
  position: absolute;
  height: 100%;
  width: auto;
  margin: 0.5px 0px 0px 4px;
  padding: 0px 0px 0px 7px;
  font-size: 15px;
  text-align: center;
  color: #353535;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  background: #fcfcfc;
  border-radius: 20px !important;
}

.pfheader {
  display: block;
  position: relative;
  margin: 0px 0px 7px 0px;
  font-size: 15.5px;
  font-weight: 500;
}

.faxnbformat {
  display: block;
  position: relative;
  margin: 0px 0px 4px 0px;
  font-size: 16px;
  font-weight: bold;

}

#pf_upload_msg, #pf_choose_msg, #pf_submit_msg {
  display: block;
  margin: 8px 0px 8px 0px;
  text-align: center;
  font-size: 15px;
  font-weight: bold;
  color: #181918;
  background-color: #a5e5b3;
  border-radius: 14px;
}

#pf_submit_msg {
  padding-left: 5px;
  padding-right: 5px;
}

#faxtodiv {
  display: block;
  position: relative;
}

#faxto {
  display: block;
  width: 91%;
  max-height: 22px;
  margin: 0px 0px 20px 0px;
  padding: 0px 15px 0px 4px;
  color: #565656;
  font-size: 16px;
  font-weight: 500;
}

.up-bttn-wrapper {
  display: block;
  position: relative;
  overflow: hidden;
  padding-top: 20px;
  padding-bottom: 30px;
}

#uploadFileToFax {
  display: inline-block;
  position: absolute;
  margin-top: 2px;
  font-size: 16.5px;
  color: #737373;
  cursor: pointer;
}

#uploadFileToFax:hover {
  color: #000000;
}

#submitfax {
  padding: 7px 12px;
  font-size: 15px;
  font-weight: 600;
  border: none;
  color: #ffffff;
  background: #5A8FD4;
  border-radius: 4.5px;
  cursor: pointer;
}

#submitfax:hover {
  background: #4f7fbe;
}

#submitfax:active {
  background: #406597;
}

.uploadfiledv {
  position: relative;
  margin: 12px 0px 36px 0px;
}

#uploadedjpg, #uploadedpng {
  width: auto !important;
  height: auto !important;
}

.balancetooltip {
  position: relative;
  display: inline-block;
  float: right;
  font-size: 15px;
  color: #000000;
  z-index: 4;
}

#balancetipInfo {
  display: block;
  position: relative;
  margin: 0px 9px 0px 0px;
  color: #000000;
  font-size: 21px;
  font-weight: bold;
  font-family: Times New Roman;
  font-style: italic;
}

.balancetipText {
  display: block;
  position: absolute;
  visibility: hidden;
  width: 264px;
  height: auto;
  background-color: #fafafa;
  font-size: 14px;
  font-weight: 600;
  color: #363636;
  text-align: left;
  border-radius: 1px;
  padding: 5px 5px 10px 10px;
  margin: -8px 0px 0px -250px;
  -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
  box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
}

.balancetooltip:hover .balancetipText {
  visibility: visible;
}

.fortooltipinit {
  position: relative;
  display: inline-block;
  float: right;
  font-size: 15px;
  color: #000000;
  z-index: 3;
}

.fortooltipinit #infosetid {
  display: block;
  position: relative;
  margin: 0px 9px 0px 0px;
  color: #000000;
  font-size: 21px;
  font-weight: bold;
  font-family: Times New Roman;
  font-style: italic;
}

.fortooltip {
  position: relative;
  display: inline-block;
  font-size: 15px;
  color: #000000;
  z-index: 2;
}

.fortooltip #infonumber {
  color: #000000;
  font-size: 21px;
  font-weight: bold;
  font-family: Times New Roman;
  font-style: italic;
  padding: 0px 0px 3px 3px;
}

.fortooltipsec {
  position: relative;
  display: inline-block;
  font-size: 15px;
  color: #000000;
  padding: 0px;
  z-index: 1;
}

.fortooltipsec #infoformat {
  color: #000000;
  font-size: 21px;
  font-weight: bold;
  font-family: Times New Roman;
  font-style: italic;
  padding: 0px 0px 3px 3px;
}

.fortooltipinit .calleridtooltip {
  display: block;
  position: absolute;
  visibility: hidden;
  width: 264px;
  height: auto;
  background-color: #fafafa;
  font-size: 14px;
  font-weight: 600;
  color: #363636;
  text-align: left;
  border-radius: 1px;
  padding: 5px 5px 10px 10px;
  margin: -7px 0px 0px -250px;
  -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
  box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
}

.fortooltipinit:hover .calleridtooltip {
  visibility: visible;
}

.fortooltip .fortooltiptext {
  display: block;
  position: absolute;
  visibility: hidden;
  width: 280px;
  height: auto;
  background-color: #fafafa;
  font-size: 14px;
  font-weight: 600;
  color: #363636;
  text-align: left;
  border-radius: 1px;
  padding: 5px 5px 10px 10px;
  margin: -11px 0px 0px -10px;
  -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
  box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
}

.fortooltip:hover .fortooltiptext {
  visibility: visible;
}

.fortooltipsec .fortooltiptextsec {
  display: block;
  position: absolute;
  visibility: hidden;
  width: 280px;
  height: auto;
  background-color: #fafafa;
  font-size: 14px;
  font-weight: 600;
  color: #363636;
  text-align: left;
  border-radius: 1px;
  padding: 5px 5px 10px 10px;
  margin: -10px 0px 0px -10px;
  -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
  box-shadow: 0 0 23px rgba(0, 0, 0, 0.3);
}

.fortooltipsec:hover .fortooltiptextsec {
  visibility: visible;
}

.fileupload {
  display: none;
}

#srfax_vbar label span {
  display: inline-block;
  min-width: 110px;
  padding: 0px 0px 8px 0px;
}

.uploadflbt .icon-upload {
  display: inline;
}

.pfprompt {
  font-size: 17px;
  font-weight: bold;
  color: #6d6c6c;
}

.fileuploadstl {
  display: block;
  font-size: 17px;
  font-weight: bold;
  color: #000000;
  min-height: 40px;
}

#filestotsize {
  display: none;
  position: relative;
  height:auto;
  margin: 0px 0px 16px 0px;
  color: #18bf6e;
  font-size: 15px;
  font-weight: bold;
}

#filessizetext {
  display: inline;
  position: relative;
  padding-left: 10px;
}

/* #fileuploadednm */

.indivflcls {
  display: inline-block;
  position: relative;
  height:auto;
  max-width: 90%;
  overflow: visible;
  white-space: normal;
  word-break: break-all;
  text-overflow: ellipsis;
  font-size: 15px;
  text-decoration: none;
  color: #0e6ba0;
  cursor: pointer;
}

.indivflcls:hover {
  color: #0f89cf;
}

.indupfldl {
  position: relative;
  display: inline-block;
  float: right;
  cursor: pointer;
  width: 20px;
  color: #0e6ba0;
  text-align: center;
  font-size: 15px;
}

.indupfldl:hover {
  color: #b40303;
  cursor: pointer;
}

/* #filespickednc */

.indivflpckd {
  display: inline-block;
  position: relative;
  height:auto;
  max-width: 90%;
  overflow: visible;
  white-space: normal;
  word-break: break-all;
  text-overflow: ellipsis;
  color: #0e6ba0;
}

.indivflpckd:hover {
  cursor: pointer;
  text-decoration: underline;
}

.indpckfldl {
  position: relative;
  display: inline-block;
  float: right;
  cursor: pointer;
  width: 20px;
  color: #0e6ba0;
  text-align: center;
}

#filespickednc .indpckfldl:hover {
  background-color: #e8f6ff;
  cursor: pointer;
}

#dirbuttons {
  display: block;
  position: relative;
  margin: 40px 0px 30px 0px;
}

#uploadfileforfax {
  margin-left: 19px;
}


#uploadFile {
  display: inline-block;
  position: relative;
  font-size: 16px;
  font-weight: bold;
  color: #6d6c6c;
}

#currentbaldiv #balanceText {
  display: inline-block;
  position: relative;
  font-size: 16px;
  font-weight: 700;
  margin: 3px 3px 2px 13px;
  color: #ffffff;
}

#faxnumbersdiv #pickid {
  display: inline-block;
  position: relative;
  font-size: 16px;
  font-weight: 700;
  margin: 3px 3px 2px 13px;
  color: #ffffff;
}

#get_notification {
  display: block;
  margin-bottom: 8px;
}

#get_notification:hover {
  cursor: pointer;
}

#countryCallCode {
  color: #1b60ba;
}

#countryCallCode:hover {
  color: #0D3B78;
}

.openfaxfolder {
  display: block;
  position: relative;
  margin: 10px 0px 10px 0px;
  padding: 7px 0px 7px 0px;
  width: 100%;
  color: #ffffff;
  font-size: 15px;
  font-weight: 600;
  background: #c68fbf;
  border: none;
  outline: none;
}

.openfaxfolder:hover {
  border: none;
  outline: none;
  background: #b381ac;
}

.openfaxfolder:active {
  background: #9e6d97;
}

.openfaxfolder:focus {
  background: #a3669b;
}

/*.indgenflcls, .indgenpckfls { */

.indgenflcls {
  display: block;
  margin: 0px 3px 14px 3px;
  padding: 0px 3px 0px 6px;
  border-radius: 5px;
}

.indgenflcls:hover {
  background-color: #ecf4fb;
}

#centeredFaxIc {
  display: block;
  position: absolute;
  font-size: 110px;
  top: 50%;
  left: 50%;
  margin-top: -55px;
  margin-left: -55px;
  color: #dbdbdb;
}

#currentbalance {
  display: inline-block;
  position: absolute;
  right: 34px;
  top: 4.5px;
  width: auto;
  font-size: 15px;
  font-weight: 700;
  color: #ffffff;
}
